/**
 * First we will load all of this project's JavaScript dependencies which
 * includes Vue and other libraries. It is a great starting point when
 * building robust, powerful web applications using Vue and Laravel.
 */

// require('./bootstrap');

window.colors = {
    solid: {
      primary: '#7367F0',
      secondary: '#82868b',
      success: '#28C76F',
      info: '#00cfe8',
      warning: '#FF9F43',
      danger: '#EA5455',
      dark: '#4b4b4b',
      black: '#000',
      white: '#fff',
      body: '#f8f8f8'
    },
    light: {
      primary: '#7367F01a',
      secondary: '#82868b1a',
      success: '#28C76F1a',
      info: '#00cfe81a',
      warning: '#FF9F431a',
      danger: '#EA54551a',
      dark: '#4b4b4b1a'
    }
  };

var _ = require('lodash');
window.axios = require('axios').default;

window.dateFormat = require("dateformat").default;

//window.Vue = require('vue');
import Vue from 'vue'

window.VueEvent = new Vue();

import { BootstrapVue } from 'bootstrap-vue'
Vue.use(BootstrapVue);

// import 'bootstrap/dist/css/bootstrap.css'
import 'bootstrap-vue/dist/bootstrap-vue.css'


import draggable from 'vuedraggable';

// DatePicker https://www.npmjs.com/package/vue2-datepicker
import DatePicker from 'vue2-datepicker';
import 'vue2-datepicker/index.css';
import Swal from 'sweetalert2';
import vSelect from 'vue-select'
import 'vue-select/dist/vue-select.css';

/**
 * The following block of code may be used to automatically register your
 * Vue components. It will recursively scan this directory for the Vue
 * components and automatically register them with their "basename".
 *
 * Eg. ./components/ExampleComponent.vue -> <example-component></example-component>
 */

const files = require.context('./components', true, /\.vue$/i);
files.keys().map(key => Vue.component(key.split('/').pop().split('.')[0], files(key).default));

/**
 * Next, we will create a fresh Vue application instance and attach it to
 * the page. Then, you may begin adding components to this application
 * or customize the JavaScript scaffolding to fit your unique needs.
 */

 let appData = {};

if(window.pageData !== undefined){

    appData = window.pageData;
}

appData.siteAddressStatus =  false;
appData.returnVisitStatus =  true;
appData.opportunity = {
    companyName:"",
    contactFullName:"",
    contactPhoneNumber:"",
    contactEmail:""
};
appData.user = {
    first_name:"",
    last_name:"",
    telephone:"",
    email:""
};

appData.deliveryAddresses = null;
appData.ordersBy = null;
appData.invoices = null;
appData.addresses = null;

appData.qAuthor = appData.author_id;

const app = new Vue({
    el: '#app2',
    data: appData,
    components: {DatePicker, vSelect},
    methods: {
    	applyFormValidation() {

    		var clientForm = $('form');

			clientForm.find("input,select,textarea").not("[type=submit]")
			.jqBootstrapValidation("destroy")
			.jqBootstrapValidation({
				filter: function () {
	                return !$(this).prop("disabled");
				},
                submitError: function ($form, event, errors) {

                    // Scroll to the first invalid field
                    let topPadding = 140; // Reserve top area for sticky navigation;
                    let firstErrorPosition = $form.find('.error').first().offset();
                    $('html, body').animate({ scrollTop: firstErrorPosition.top - topPadding });
                }
	      	});
    	},
        getOpportunity(id){

            var data ={
                "id": id,
                "_token": csrf_token
            };

            var $this = this;

            $.post(
                '/opportunities/fetch-opportunity',
                data,
                function(response) {

                    $this.opportunity = response;

                }
            );

        },
        getUser(id){

            var data ={
                "id": id,
                "_token": csrf_token
            };

            var $this = this;

            $.post(
                '/users/fetch-user',
                data,
                function(response) {

                    $this.user = response;

                }
            );

        },
        qAuthorChanged(id){

            this.getUser(id);
        },
        qOpportunityChanged(id){

            this.getOpportunity(id);
        },
        saveWorksheet: function(){
            axios.post('/jobs/update-worksheet', {
                "worksheet_id": this.worksheetId,
                "worksheet": JSON.stringify(this.worksheetData)
            })
            .then(function (response) {
                if(response.data.status === 'success') {
                    toastr.success('Worksheet has been submitted.');
                }
                else {
                    toastr.error('Failed to submit Worksheet, please try again later.');
                }
            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });
        },
        saveServiceReport: function(worksheetId, serviceReport){
            axios.post(' /jobs/update-service-report', {
                "worksheet_id": worksheetId,
                "service_report_id": serviceReport.id,
                "service_report": JSON.stringify(serviceReport.data)
            })
            .then(function (response) {
                if(response.data.status === 'success') {

                    this.serviceReports =  this.serviceReports.map(o => {
                        if (o.id == serviceReport.id) o.data = serviceReport.data;
                        return o;
                    });

                    toastr.success('Service report has been submitted.');
                }
                else {
                    toastr.error('Failed to submit Service report, please try again later.');
                }
            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });
        },
        deleteServiceReport: function(id){
            axios.post(' /jobs/delete-service-report', {
                "service_report_id": id
            })
            .then(function (response) {
                if(response.data.status === 'success') {

                    this.serviceReports = _.filter(this.serviceReports, function(o) { return o.id != id; });
                    toastr.success('Service report has been deleted.');
                }
                else {
                    toastr.error('Failed to delete Service report, please try again later.');
                }
            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });
        },

        contentDelete(contentType, contentId, deleteRoute){

            const swalWithBootstrapButtons = Swal.mixin({
              customClass: {
                confirmButton: 'btn btn-danger mr-1',
                cancelButton: 'btn btn-light'
              },
              buttonsStyling: false
            });

            swalWithBootstrapButtons.fire({
              title: 'Are you sure?',
              text: "You won't be able to revert this!",
              icon: 'warning',
              showCancelButton: true,
              confirmButtonText: 'Delete',
              cancelButtonText: 'Cancel',
              showLoaderOnConfirm: true,
              preConfirm: () => {
                var url = deleteRoute;
                var data = new FormData();
                data.append( contentType + "Id", contentId );
                data.append( "_token", csrf_token );

                return fetch(url, {
                    method: 'POST', // or 'PUT'
                    body: data, // data can be `string` or {object}!
                })
                .then(response => {

                    if (!response.ok) {
                      throw new Error(response.statusText)
                    }
                    return response.json()
                })
                .catch(error => {
                    Swal.showValidationMessage(
                      'Request failed. Please try again later'
                    )
                })
              },
              allowOutsideClick: () => !Swal.isLoading()
            })
            .then((result) => {

              if (result.value[0] === "success") {
                Swal.fire(
                    'Deleted!',
                    contentType + ' has been deleted.',
                    'success'
                );

                $("tr[data-"+contentType+"-contentId='"+contentId+"']").fadeOut("slow", function() {
                    $(this).remove();
                });

              }
              else if (result.value[0] === "fail") {
                Swal.fire(
                    "Something went wrong",
                    "Please try again later",
                    "error"
                )
              }
            })
        },
        noteContentPopulate(contentId){

            let noteData = $("[data-note-content-id='"+contentId+"']");

            $("#modal-note #modal-note-title").html(noteData.data("note-content-title"));
            $("#modal-note #modal-note-content").html(noteData.html());
        },

        popConfirmBox({target}) {
            let swalWithBootstrapButtons = Swal.mixin({
                customClass: {
                    confirmButton: 'btn btn-danger mr-1',
                    cancelButton: 'btn btn-light'
                },
                buttonsStyling: false
            });

            target = target.closest('button');

            swalWithBootstrapButtons.fire({
                title: target.dataset.originalTitle,
                html: target.dataset.text,
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: target.dataset.confirmText,
                cancelButtonText: target.dataset.cancelText,
                showLoaderOnConfirm: true,
                preConfirm: () => {
                    if(target.dataset.formIdToSubmit !== undefined) {
                        $('#' + target.dataset.formIdToSubmit).submit();
                    } else {
                        window.location = target.dataset.successRoute;
                    }
                },
                allowOutsideClick: () => !Swal.isLoading()
            })
        },

        getOrdersBy: function(userIds){

            axios.post('/users/fetch-all', {
                "ids": userIds,
                "_token": csrf_token
            })
            .then(function (response) {

                this.ordersBy =response.data;

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },
        saveInvoice: function(){

            let saveInvoiceButton = $('#save-invoice');
            let formSaveInvoice = saveInvoiceButton.parents('form').first();

            formSaveInvoice.submit(function(e){

                e.preventDefault(e);

                const formData = new FormData(this);
                formData.append( "_token", csrf_token );
                const entries = formData.entries();
                const data = Object.fromEntries(entries);

                if (data.invoice_id.length > 0){
                    axios.post('/invoices/ajax/update', data)
                    .then(function (response) {

                        if(response.data.status === 'success') {
                            toastr.success('Invoice has been updated.');

                            VueEvent.$emit('toggleSidebar', 'sidebar-invoice');
                        }
                        else {
                            toastr.error('Failed to update invoice, please try again later.');
                        }

                    }.bind(this))
                    .catch(function (error) {
                        console.log(error);
                    });
                }
                else{
                    axios.post('/invoices/ajax/update', data)
                    .then(function (response) {

                        if(response.data.status === 'success') {
                            toastr.success('Invoice has been added.');

                            VueEvent.$emit('toggleSidebar', 'sidebar-invoice');
                        }
                        else {
                            toastr.error('Failed to add invoice, please try again later.');
                        }

                    }.bind(this))
                    .catch(function (error) {
                        console.log(error);
                    });
                }
            });
        },
        deleteInvoice: function(id){
            axios.post('/invoices/ajax/delete', {
                "invoice_id": id,
                "_token": csrf_token
            })
            .then(function (response) {

                if(response.data.status === 'success') {
                    toastr.success('Invoice has been deleted.');
                    this.invoices = _.filter(this.invoices, function(o) { return o.id != id; });
                }
                else {
                    toastr.error('Failed to delete invoice, please try again later.');
                }

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },
        toggleSidebar(sidebar){
             this.$root.$emit('bv::toggle::collapse', sidebar);
        },
        pdfPreview(source, sidebar){
            let pdfPreviewWrapper = document.getElementById("pdfPreviewWrapper");

            document.getElementById("pdfPreview").remove();

            this.toggleSidebar(sidebar);

            let pdfPreview = document.createElement("iframe");
            pdfPreview.name = "preview"
            pdfPreview.id = "pdfPreview"
            pdfPreview.width = "100%"
            pdfPreview.src = source;
            pdfPreviewWrapper.appendChild(pdfPreview).focus();

        },
        showSidebar(sidebar){
            $('body').addClass('modal-open');
            $("#"+sidebar).find(".js-sidebar-content").addClass("show");
            $(".overlay-bg").addClass("show");
        },
        getAddresses: function(parentClass,parentId){

            if(!parentClass || !parentId) return

            axios.post('/addresses/fetch', {
                "parent_class": parentClass,
                "parent_id": parentId,
                "_token": csrf_token
            })
            .then(function (response) {
                if(response.data.status === 'success') {
                    this.addresses = response.data.data;
                }
                else{
                    console.log(response.errors);
                }

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },
        saveAddressListener: function(bindEvent = true){
            let saveAddressButton = $('#save-address');
            let formSaveAddress = saveAddressButton.parents('form').first();


            if (!bindEvent) {
                // remove all submit events
                formSaveAddress.off("submit");
                return
            }

            formSaveAddress.submit(function(e){

                e.preventDefault(e);

                const formData = new FormData(this);
                const entries = formData.entries();
                const data = Object.fromEntries(entries);

                VueEvent.$emit('saveAddress', data);

            });
        },
        saveAddress: function(data){

            let addressType = data.address_type;

            data._token = csrf_token;

            if (this.child_id){
                // child found
                data.address_type = '';
            }
            else{
                // child not found
            }

            if (data.address_id.length > 0){
                axios.post('/addresses/update', data)
                .then(function (response) {

                    if(response.data.status === 'success') {
                        // toastr.success('Address has been updated.');

                        if (this.child_id){
                            this.setAddress(response.data.address, addressType);
                        }
                        else{
                            this.toggleSidebar('sidebar-address-book');
                        }

                        this.toggleSidebar('sidebar-address');
                        this.updateAddress(response.data.address);

                    }
                    else {
                        toastr.error('Failed to update address, please try again later.');
                    }

                }.bind(this))
                .catch(function (error) {
                    console.log(error);
                });
            }
            else{
                axios.post('/addresses/add', data)
                .then(function (response) {

                    if(response.data.status === 'success') {
                        // toastr.success('Address has been added.');

                        if (this.child_id){
                            this.setAddress(response.data.address, addressType);
                        }
                        else{
                            this.toggleSidebar('sidebar-address-book');
                        }

                        this.toggleSidebar('sidebar-address');
                        this.updateAddressList(response.data.address, addressType);

                    }
                    else {
                        toastr.error('Failed to add address, please try again later.');
                    }

                }.bind(this))
                .catch(function (error) {
                    console.log(error);
                });
            }

        },

        updateAddress: function(address){
            this.address_types =  this.address_types.map(o => {
                if (o.value !== null && o.value.id == address.id) o.value = address;
                return o;
            });
            this.addresses =  this.addresses.map(o => {
                if (o.id == address.id) o = address;
                return o;
            });
        },

        updateAddressList: function(address, addressType){

            this.addresses.push(address);

            let currentAddressTypeIndex = _.findIndex(this.address_types, {'slug': addressType});
                this.address_types[currentAddressTypeIndex].value = address;
        },
        deleteAddress: function(id){
            axios.post('/addresses/delete', {
                "address_id": id,
                "_token": csrf_token
            })
            .then(function (response) {

                if(response.data.status === 'success') {
                    toastr.success('Address has been deleted.');
                    this.addresses = _.filter(this.addresses, function(o) { return o.id != id; });

                    this.address_types =  this.address_types.map(o => {
                        if (o.value !== null && o.value.id == id) o.value = null;
                        return o;
                    });
                }
                else {
                    toastr.error('Failed to delete address, please try again later.');
                }

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },
        setAddress: function(address, addressType){



            axios.post('/addresses/set-type', {
                "address_id": address.id,
                "address_type": addressType,
                "parent_class": (this.child_class)? this.child_class : this.parent_class,
                "parent_id": (this.child_id)? this.child_id : this.parent_id,
                "_token": csrf_token
            })
            .then(function (response) {

                if(response.data.status === 'success') {
                    // toastr.success('Address has been selected.');
                    let currentAddressTypeIndex = _.findIndex(this.address_types, {'slug': addressType});
                    this.address_types[currentAddressTypeIndex].value = address;
                    this.toggleSidebar('sidebar-address-book');
                }
                else {
                    toastr.error('Failed to select address, please try again later.');
                }

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },
        unsetAddress: function(addressType){
            axios.post('/addresses/unset-type', {

                "address_type": addressType,
                "parent_class": (this.child_class)? this.child_class : this.parent_class,
                "parent_id": (this.child_id)? this.child_id : this.parent_id,
                "_token": csrf_token
            })
            .then(function (response) {

                if(response.data.status === 'success') {
                    // toastr.success('Address has been unset.');
                    let currentAddressTypeIndex = _.findIndex(this.address_types, {'slug': addressType});
                    this.address_types[currentAddressTypeIndex].value = null;
                }
                else {
                    toastr.error('Failed to unset address, please try again later.');
                }

            }.bind(this))
            .catch(function (error) {
                console.log(error);
            });

        },

    },
    created(){
        VueEvent.$on('updateTooltip', ()=> $('[data-toggle="tooltip"]').tooltip());
        VueEvent.$on('updateFormValidation', ()=> this.applyFormValidation());
        VueEvent.$on('deleteNewContent', (contentType, contentId, routePrefix)=> this.contentDelete(contentType, contentId, routePrefix));
        VueEvent.$on('e_noteContentPopulate', (contentId)=> this.noteContentPopulate(contentId));
        VueEvent.$on('saveWorksheet', ()=> this.saveWorksheet());
        VueEvent.$on('saveServiceReport', (worksheetId, serviceReport)=> this.saveServiceReport(worksheetId, serviceReport));
        VueEvent.$on('deleteServiceReport', (id)=> this.deleteServiceReport(id));
        VueEvent.$on('deleteItem', (target)=> this.popConfirmBox(target));
        VueEvent.$on('pdfPreview', (previewRoute, sidebarId)=> this.pdfPreview(previewRoute, sidebarId));

        VueEvent.$on('updateOrders', (orders)=> {
            this.orderOptions = orders;

            let userIds = this.orderOptions.map(d => d.order_by);
            this.getOrdersBy(userIds);
        });

        VueEvent.$on('updateSelectedDeliveries', (selectedDeliveries)=> this.deliveryIds = selectedDeliveries);
        VueEvent.$on('updateSelectedOrders', (selectedOrders)=> this.orderIds = selectedOrders);

        //VueEvent.$on('getInvoices', (parentClass, parentId)=>this.getInvoices(parentClass, parentId));
        // VueEvent.$on('editInvoice', (id)=>this.editInvoice(id) );
        // VueEvent.$on('updateInvoice', (id)=>this.updateInvoice(id) );
        VueEvent.$on('deleteInvoice', (id) => this.deleteInvoice(id) );
        //VueEvent.$on('toggleSidebar', (sidebar) => this.toggleSidebar(sidebar) );

        VueEvent.$on('getAddresses', ()=>this.getAddresses(this.parent_class, this.parent_id) );
        VueEvent.$on('setAddress', (address, addressType)=>this.setAddress(address, addressType) );
        VueEvent.$on('unsetAddress', (addressType)=>this.unsetAddress(addressType, this.parent_class, this.parent_id) );
        VueEvent.$on('saveAddress', (data)=>this.saveAddress(data) );
        VueEvent.$on('saveAddressListener', (bindEvent)=>this.saveAddressListener(bindEvent) );

        //VueEvent.$on('updateAddress', (address)=>this.updateAddress(address) );
        //VueEvent.$on('updateAddressList', (address, addressType)=>this.updateAddressList(address, addressType) );
        VueEvent.$on('deleteAddress', (id) => this.deleteAddress(id) );

        VueEvent.$on('updateParent', (parentClass, parentId)=>{
                this.parent_class = parentClass;
                this.parent_id = parentId;
            });

        VueEvent.$on('updateClientId', (clientId)=> {this.clientId = clientId});
        VueEvent.$on('updateOpportunityId', (opportunityId)=> {this.opportunityId = opportunityId});
        VueEvent.$on('updateOpportunity', (opportunity)=> {this.opportunity = opportunity});

        VueEvent.$on('updateAuthorId', (authorId)=> {this.author_id = authorId});
        VueEvent.$on('updateTitle', (title)=> {this.name = title});
        VueEvent.$on('updateRef', (ref)=> {this.internal_ref = ref});


    },
    watch: {
        parent_id(){
            VueEvent.$emit('getAddresses');
        }
    },
    mounted() {

        $(".select2").not('.no-search').select2();
        $(".select2.no-search").select2({
            minimumResultsForSearch: Infinity,
        });

        this.applyFormValidation();
        this.saveInvoice();
        this.saveAddressListener();

        this.getUser(this.author_id);
        this.getOpportunity(this.quotable_id);

        let params = new URLSearchParams(document.location.search.substring(1));
        let panel = params.get('panel');

        if (panel){
            this.toggleSidebar('sidebar-'+panel);
        }
    }
});

window.vApp = app;
