@extends('layouts.contentLayoutMaster')

@section('title')
    {{$object->company_name}}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('clients'),
            'name' =>'Companies'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')
    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('client-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['client-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}

        @csrf

        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">


                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Company Details</h4>
                            <div class="pull-right mb-1">
                                <b-button
                                    variant="primary"
                                    class="show-data-sidebar"
                                    data-sidebar-content="sidebar-job-sheets">
                                    <i class="feather icon-paperclip"></i>
                                    Job Sheets
                                </b-button>
                                <b-button
                                    variant="primary"
                                    class="show-data-sidebar"
                                    data-sidebar-content="sidebar-purchase-orders">
                                    <i class="feather icon-paperclip"></i>
                                    Purchase Orders
                                </b-button>
                                <b-button
                                    variant="primary"
                                    class="show-data-sidebar"
                                    data-sidebar-content="sidebar-delivery-notes">
                                    <i class="feather icon-paperclip"></i>
                                    Delivery Notes
                                </b-button>
                                <b-button
                                    variant="primary"
                                    class="show-data-sidebar"
                                    data-sidebar-content="sidebar-asset-lists">
                                    <i class="feather icon-paperclip"></i>
                                    Asset Lists
                                </b-button>
                                @include('elements.document-note-buttons')
                            </div>

                        </div>
                        <div class="card-content">
                            <div class="card-body">

                                <div class="form-body">
                                    <div class="row">
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('company_name', 'Company Name *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('company_name', old('company_name'), [
                                                            'id' => 'company_name',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['company_name'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-12"></div>
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('telephone', 'Telephone') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('telephone', old('telephone'), [
                                                            'id' => 'telephone',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['telephone'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('fax', 'Fax') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('fax', old('fax'), [
                                                            'id' => 'fax',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['fax'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('email', 'Email') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::email('email', old('email'), [
                                                            'id' => 'email',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['email'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('website', 'Website') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('website', old('website'), [
                                                            'id' => 'website',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['website'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12 col-md-6">
                                            <div class="form-group">
                                                {!! Form::label('industries', 'Industry') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('industries[]', $industries['options'], old('industries'),
                                                        [
                                                            'id' => 'industries',
                                                            'class' => 'select2 form-control',
                                                            'multiple' => 'multiple'
                                                        ] + $validationRules['industries'], $industries['optionAttributes'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12 col-md-6">
                                            <div class="form-group">
                                                {!! Form::label('status', 'Status *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('status', $statuses['options'], old('status', app('request')->input('status') != null ? app('request')->input('status') : null),
                                                        [
                                                            'id' => 'status',
                                                            'class' => 'select2 form-control',
                                                        ] + $validationRules['status'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12 col-md-6">
                                            <div class="form-group">
                                                {!! Form::label('subtype', 'Sub Type') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('subtype', $subTypes['options'], old('subtype', app('request')->input('subtype') != null ? app('request')->input('subtype') : null),
                                                        [
                                                            'id' => 'subtype',
                                                            'class' => 'select2 form-control',
                                                        ] + $validationRules['subtype'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12 col-md-6">
                                            <div class="form-group">
                                                {!! Form::label('client_manager_id', 'Client Manager *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('client_manager_id', $clientManagers['options'], old('client_manager_id', app('request')->input('client_manager_id') != null ? app('request')->input('client_manager_id') : null),
                                                        [
                                                            'id' => 'client_manager_id',
                                                            'class' => 'select2 form-control',
                                                        ] + $validationRules['client_manager_id'], $clientManagers['optionAttributes'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12 col-md-6">
                                            <div class="form-group">
                                                {!! Form::label('worksheet_id', 'Default Worksheet') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('worksheet_id', $worksheets['options'], old('worksheet_id', app('request')->input('worksheet_id') != null ? app('request')->input('worksheet_id') : null),
                                                        [
                                                            'id' => 'worksheet_id',
                                                            'class' => 'select2 form-control',
                                                        ] + $validationRules['worksheet_id'], $worksheets['optionAttributes'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <div class="row">

                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('clients')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    {{ Form::close() }}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ],
            [
                'id' => 'sidebar-job-sheets',
                'title' => 'Job sheet documents',
                'uploadRouteName' => $routePrefixSingular . '-job-sheet-upload',
                'documents' => $object->jobSheets()
            ],
            [
                'id' => 'sidebar-purchase-orders',
                'title' => 'Purchase order documents',
                'uploadRouteName' => $routePrefixSingular . '-purchase-order-upload',
                'documents' => $object->purchaseOrders()
            ],
            [
                'id' => 'sidebar-delivery-notes',
                'title' => 'Delivery notes documents',
                'uploadRouteName' => $routePrefixSingular . '-delivery-note-upload',
                'documents' => $object->deliveryNotes()
            ],
            [
                'id' => 'sidebar-asset-lists',
                'title' => 'Asset lists documents',
                'uploadRouteName' => $routePrefixSingular . '-asset-list-upload',
                'documents' => $object->assetLists()
            ]
        ]
    ])
    @include('elements.notes-side-panel')

@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/ajaxIndexTable.js') }}"></script>
@endsection
