@extends('layouts.contentLayoutMaster')

@section('title')
    Create a Contract
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('contracts'),
            'name' =>'Contracts'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::open(['route' => ['contract-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">


                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Contract Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Title *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name', isset($selectedOpportunity) ? $selectedOpportunity->name : null), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('type', 'Contract Type *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('type', $types['options'], old('type'),
                                                        ['id' => 'type', 'class' => 'select2 form-control'] + $validationRules['type'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id', $selectedClientId),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('service_level_agreement_id', 'Service Level Agreement *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('service_level_agreement_id', $serviceLevelAgreements['options'], old('service_level_agreement_id'),
                                                    [
                                                        'id' => 'service_level_agreement_id',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['service_level_agreement_id'], $serviceLevelAgreements['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('call_out_included', 'Call Out Included *') !!}
                                            <div class="controls">
                                                <b-form-radio-group
                                                    id="call_out_included"
                                                    v-model="call_out_included"
                                                    name="call_out_included"
                                                    buttons
                                                    button-variant="outline-primary"
                                                >
                                                    <b-form-radio value="1">Yes</b-form-radio>
                                                    <b-form-radio value="0">No</b-form-radio>
                                                </b-form-radio-group>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id', $selectedSiteId),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('customer_purchase_order_id', 'Purchase Order *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('customer_purchase_order_id', $customerPurchaseOrders['options'], old('customer_purchase_order_id', $purchaseOrderId),
                                                        ['id' => 'customer_purchase_order_id', 'class' => 'select2 form-control'] + $validationRules['customer_purchase_order_id'], $customerPurchaseOrders['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group @if($contacts['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('contact_id', 'Main Contact *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('contact_id', $contacts['options'], old('contact_id'),
                                                        ['id' => 'contact_id', 'class' => 'select2 form-control'] + $validationRules['contact_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12" id="Opportunity">
                                        <div class="form-group">
                                            {!! Form::label('opportunity_id', 'Opportunity *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('opportunity_id', $opportunities['options'], old('opportunity_id', isset($selectedOpportunity) ? $selectedOpportunity->id : null),
                                                        ['id' => 'opportunity_id', 'class' => 'select2 form-control'] + $validationRules['opportunity_id'], $opportunities['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('start_date', 'Start Date *') !!}
                                            <div class="controls">
                                                <input type="hidden" name="start_date" :value="start_date">
                                                <date-picker
                                                    id="start_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="start_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('expiry_date', 'Expiry Date *') !!}
                                            <div class="controls">
                                                <input type="hidden" name="expiry_date" :value="expiry_date">
                                                <date-picker
                                                    id="expiry_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="expiry_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('current_status', 'Current Status *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('current_status', $statuses['options'], old('current_status'),
                                                        ['id' => 'current_status', 'class' => 'select2 form-control'] + $validationRules['current_status'], $statuses['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('service_visits', 'Service Visits') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('service_visits[]', $months['options'], old('service_visits', []),
                                                        ['id' => 'service_visits', 'class' => 'select2 form-control', 'multiple' => 'multiple'] + $validationRules['service_visits'], $clients['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('details', 'Details') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::textarea('details', old('details'), [
                                                        'id' => 'details',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['details'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('price_per_visit', 'Price Per Visit') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('price_per_visit', old('price_per_visit'), [
                                                        'id' => 'price_per_visit',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['price_per_visit'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('price_per_month', 'Price Per Month') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('price_per_month', old('price_per_month'), [
                                                        'id' => 'price_per_month',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['price_per_month'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('price_per_annum', 'Price Per Annum') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('price_per_annum', old('price_per_annum'), [
                                                        'id' => 'price_per_annum',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['price_per_annum'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('worksheet_id', 'Default Worksheet') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('worksheet_id', $worksheets['options'], old('worksheet_id', app('request')->input('worksheet_id') != null ? app('request')->input('worksheet_id') : env('DEFAULT_WORKSHEET_ID')),
                                                    [
                                                        'id' => 'worksheet_id',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['worksheet_id'], $worksheets['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('contracts')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

@endsection

@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
