@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@section('vendor-style')
{{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('contract-edit', $object->id) }}"
        ><i class="feather icon-edit"></i> Edit Contract
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-12">
                <div class="card">
                    <div class="card-body pb-0">

                        <div class="pull-right">

                            <button
                                type="button"
                                class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                data-sidebar-content="sidebar-documents">
                                <i class="feather icon-paperclip"></i>
                                Documents
                            </button>
                        </div>

                    </div>
                </div>
            </div>
            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header object-toolbar">
                        <h4 class="card-title mb-25">Contract Details</h4>
                        <span class="badge badge-info"> {{$object->type}} </span>
                    </div>

                    <div class="card-content">
                        <div class="card-body">


                            <div class="row">
                                @if(!empty($object->clientName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('client-view', $object->client_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->clientName()}}</h6>
                                            <small>Company</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->siteName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('site-view', $object->site_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->siteName()}}</h6>
                                            <small>Site</small>
                                        </b-link>
                                    </div>
                                @endif
                                @if(!empty($object->start_date) || !empty($object->expiry_date))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <h6 class="mb-0">Start Date</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->start_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                        <div class="media-body">
                                            <h6 class="mb-0">Expiry Date</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->expiry_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                    </div>

                                @endif

                                @if(!empty($object->serviceLevelAgreement))
                                    <div class="col-xl-12 col-lg-12 mb-2">

                                        <h6 class="mb-25">Service Level Agreement</h6>
                                        <span class="badge badge-secondary"> {{ $object->serviceLevelAgreement->name }} </span>
                                    </div>
                                @endif

                                @if(!empty($object->call_out_included))
                                    <div class="col-xl-12 col-lg-12 mb-2">

                                        <h6 class="mb-25">Call Out Included?</h6>
                                        <span class="badge badge-secondary"> {{ $object->call_out_included ? 'Yes' : 'No' }} </span>
                                    </div>
                                @endif

                                @if (!empty($object->visits))
                                    <div class="col-xl-12 col-lg-12 mb-2">

                                        <h6 class="mb-25">Service Visits</h6>
                                        @foreach ($object->visits as $visit)
                                            <span class="badge badge-secondary"> {{$visit->visit_month}} </span>
                                        @endforeach
                                    </div>
                                @endif

                                @if (!empty($object->price_per_visit)
                                    || !empty($object->price_per_month)
                                    || !empty($object->price_per_annum)
                                )
                                    <div class="col-12"><hr class="mt-0"></div>
                                @endif
                                @if (!empty($object->price_per_visit))
                                    <div class="col-xl-4 col-lg-4 mb-1">
                                        <h6 class="mb-0">£{{ $object->price_per_visit }}</h6>
                                        <small>per visit</small>
                                    </div>
                                @endif
                                @if (!empty($object->price_per_month))
                                    <div class="col-xl-4 col-lg-4 mb-1">
                                        <h6 class="mb-0">£{{ $object->price_per_month }}</h6>
                                        <small>per month</small>
                                    </div>
                                @endif
                                @if (!empty($object->price_per_annum))
                                    <div class="col-xl-4 col-lg-4 mb-1">
                                        <h6 class="mb-0">£{{ $object->price_per_annum }}</h6>
                                        <small>per annum</small>
                                    </div>
                                @endif

                                @if (!empty($object->price_per_visit)
                                    || !empty($object->price_per_month)
                                    || !empty($object->price_per_annum)
                                )
                                    <div class="col-12"><hr class="mt-0"></div>
                                @endif

                                @if (!empty($object->details))
                                    <div class="col-xl-12 col-lg-12 mb-1">

                                        <h6 class="mb-0">Details</h6>
                                        <p>{{ $object->details }}</p>
                                    </div>
                                @endif

                                    @if(!empty($object->opportunity_id))

                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                            <div class="media-body">
                                                <b-link href="{{ route('opportunity-edit', $object->opportunity_id) }}"
                                                        v-b-tooltip.hover.left title="View" >
                                                    <h6 class="mb-0">
                                                        {{$object->opportunity->name}}
                                                        <span class="badge badge-secondary"> {{$object->opportunity->status}} </span>
                                                    </h6>
                                                    <small>Opportunity</small>
                                                </b-link>
                                            </div>
                                        </div>

                                    @endif

                                    @if(!empty($object->customer_purchase_order_id))

                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                            <div class="media-body">
                                                <b-link href="{{ route('customer-purchase-order-view', $object->customer_purchase_order_id) }}"
                                                        v-b-tooltip.hover.left title="View" >
                                                    <h6 class="mb-0">
                                                        {{$object->purchaseOrder->name}}
                                                        <span class="badge badge-secondary"> {{$object->purchaseOrder->status}} </span>
                                                    </h6>
                                                    <small>Purchase Order</small>
                                                </b-link>
                                            </div>
                                        </div>

                                    @endif

                            </div>
                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <notes
                                :notes="processedNotes"
                                :parent-class="parent_class"
                                :parent-id="parent_id"
                                save-route="{{ '/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                delete-route="{{ '/'.$routePrefixPlural.'/delete-note'}}"
                            ></notes>

                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-5 col-lg-5 col-md-5">
                @include('elements.serviceVisits', [
                    'createUrlParamName' => 'contractId',
                    'accessorField' => 'serviceVisitJobs',
                    'take' => 5,
                ])
                @include('elements.callOutJobs', [
                    'createUrlParamName' => 'contractId',
                    'accessorField' => 'callOutJobs',
                    'take' => 5,
                ])
            </div>
            <div class="col-xl-3 col-lg-3 col-md-3">
                <div class="card plan-card border-primary">
                    <div class="card-header d-flex justify-content-between align-items-center pt-75">
                        <h5 class="mb-0"> Last Update </h5>
                        <small class="text-muted w-100">{{$object->updated_at}}</small>
                    </div>
                    <div class="card-body pt-75">

                        @if (!empty($object->contact_id))
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <h5 class="mb-50">
                                        Main Contact
                                    </h5>
                                    <h6 class="mb-25"><i class="feather icon-user"></i> {{$object->contact->fullName}}</h6>
                                    @if (!empty($object->contact->email))

                                        <a href="mailto:{{$object->contact->email}}"
                                            data-toggle="tooltip"
                                            data-placement="bottom"
                                            title="{{$object->contact->email}}"
                                            data-original-title="{{$object->contact->email}}"
                                            target="_self" class="mt-"><i class="feather icon-mail"></i> Email</a>
                                    @endif
                                    @if (!empty($object->contact->telephone))
                                        <a href="tel:{{$object->contact->telephone}}" target="_self" class="mt-25 d-block"><i class="feather icon-phone"></i> {{$object->contact->telephone}}</a>
                                    @endif
                                </div>
                            </div>
                        @endif
                    </div>
                </div>
                {{-- Invoices --}}


                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <invoices :invoices="invoices" parent-class="Contract" parent-id="{{$object->id}}"></invoices>

                        </div>
                    </div>
                </div>



            </div>




        </div>
    </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])

    <section class="data-list-view-header">
        <div class="add-new-data-sidebar" id="sidebar-service-visits">

            <div class="add-new-data js-sidebar-content w-75">

                <div class="div mt-2 px-2 d-flex new-data-title justify-content-between">
                    <div>
                        <h4>Service Visits</h4>
                    </div>
                    <div class="hide-data-sidebar">
                        <i class="feather icon-x"></i>
                    </div>
                </div>
                <div class="data-items pb-3">
                    <div class="data-fields px-2 mt-3">

                        <section id="data-list-view" class="data-list-view-header">

                            <!-- DataTable starts -->
                            <div class="table-responsive">
                                @include('jobs.serviceVisits.listingTable', ['serviceVisits' => $object->serviceVisitJobs, 'createRoute' => route('service-visit-create') . '?contractId=' . $object->id])
                            </div>
                            <!-- DataTable ends -->
                            {{-- @include('clients.sidebar-create') --}}
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <section class="data-list-view-header">
        <div class="add-new-data-sidebar" id="sidebar-call-outs">

            <div class="add-new-data js-sidebar-content w-75">

                <div class="div mt-2 px-2 d-flex new-data-title justify-content-between">
                    <div>
                        <h4>Call outs & Repairs</h4>
                    </div>
                    <div class="hide-data-sidebar">
                        <i class="feather icon-x"></i>
                    </div>
                </div>
                <div class="data-items pb-3">
                    <div class="data-fields px-2 mt-3">
                        <section id="data-list-view" class="data-list-view-header">

                            <!-- DataTable starts -->
                            <div class="table-responsive">
                                @include('jobs.callOuts.listingTable', ['callOuts' => $object->callOutJobs, 'createRoute' =>route('call-out-create')])
                            </div>
                            <!-- DataTable ends -->
                            {{-- @include('clients.sidebar-create') --}}
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>

@endsection

@section('vendor-script')


    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.parent_class = "Contract";
        window.pageData.parent_id = {{ $object->id }};
        // window.pageData.invoice_date = new Date();
        // window.pageData.payment_due_date = new Date();
    </script>

    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>


@endsection
