@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('customer-purchase-orders'),
            'name' =>'Supply Only Jobs'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')

    <b-button
        variant="outline-primary"
        class="mb-1"
        href="{{ route('customer-purchase-order-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['customer-purchase-order-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Purchase Order Details</h4>
                            <div class="pull-right">
                                @include('elements.document-note-buttons')
                            </div>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Purchase Order Number *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('description', 'Description') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('description', old('description'), [
                                                        'id' => 'description',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['description'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id'),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id'),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Opportunity">
                                        <div class="form-group @if($opportunities['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('opportunity_id', 'Opportunity *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('opportunity_id', $opportunities['options'], old('opportunity_id'),
                                                        ['id' => 'opportunity_id', 'class' => 'select2 form-control'] + $validationRules['opportunity_id'], $opportunities['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('type', 'Type *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('type', $types['options'], old('type'),
                                                        ['id' => 'type', 'class' => 'select2 form-control'] + $validationRules['type'], $statuses['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('job_date', 'Received date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="job_date" :value="job_date">
                                                <date-picker
                                                    id="job_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="job_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('date_requested', 'Date Requested') !!}
                                            <div class="controls">
                                                <input type="hidden" name="date_requested" :value="date_requested">
                                                <date-picker
                                                    id="date_requested"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="date_requested">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('net_amount', 'Net Amount £ *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('net_amount', old('net_amount'), [
                                                        'id' => 'net_amount',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['net_amount'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status'),
                                                        ['id' => 'status', 'class' => 'select2 form-control'] + $validationRules['status'], $statuses['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group @if($deliveries['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('delivery_ids', 'Deliveries') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('delivery_ids[]', $deliveries['options'], old('delivery_ids', $object->deliveries()->withTrashed()->get()),
                                                        ['id' => 'delivery_ids', 'class' => 'select2 form-control', 'multiple' => 'multiple'] + $validationRules['delivery_ids'], $deliveries['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>

                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group @if($orders['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('order_ids', 'Orders') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('order_ids[]', $orders['options'], old('order_ids', $object->orders()->withTrashed()->get()),
                                                        ['id' => 'order_ids', 'class' => 'select2 form-control', 'multiple' => 'multiple'] + $validationRules['order_ids'], $orders['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-md-6 col-12">

                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <deliveries-list :delivery-options="deliveryOptions" :delivery-ids="deliveryIds" :delivery-addresses="deliveryAddresses" view-route="{{ route('delivery-view', '') }}" create-route="{{ route('delivery-create', '') }}?purchaseOrderId={{$object->id}}"></deliveries-list>

                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-6 col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <orders-list :order-options="orderOptions" :order-ids="orderIds" :orders-by="ordersBy" edit-route="{{ route('order-edit', '') }}" create-route="{{ route('order-create', '') }}?purchaseOrderId={{$object->id}}" title="Supplier Orders"></orders-list>

                            </div>
                        </div>
                    </div>
                </div>


                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('customer-purchase-orders')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')
@endsection

@section('vendor-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.deliveryOptions = {!! json_encode($object->deliveries()->orderBy('created_at', 'desc')->get()) !!};
        window.pageData.orderOptions = {!! json_encode($object->orders()->orderBy('created_at', 'desc')->get()) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
