@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }} {{ ($object->description) ? '- '.$object->description: '' }}
@endsection

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('customer-purchase-order-edit', $object->id) }}"
    ><i class="feather icon-edit"></i> Edit Purchase Order
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-12">
                <div class="card">
                    <div class="card-body pb-0">

                        <div class="pull-right">

                            <button
                                type="button"
                                class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                data-sidebar-content="sidebar-documents">
                                <i class="feather icon-paperclip"></i>
                                Documents
                            </button>
                        </div>

                    </div>
                </div>
            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header object-toolbar">
                        <h4 class="card-title mb-25">Purchase Order Details</h4>
                        <span class="badge badge-info"> {{$object->status}} </span>
                        <span class="badge badge-info"> {{$object->type}} </span>
                    </div>

                    <div class="card-content">
                        <div class="card-body">
                            <div class="row">
                                @if(!empty($object->clientName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('client-view', $object->client_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->clientName()}}</h6>
                                            <small>Company</small>
                                        </b-link>
                                    </div>
                                @endif
                                @if(!empty($object->type))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <h6 class="mb-0">{{ $object->type }}</h6>
                                        <small>Type</small>
                                    </div>
                                @endif

                                @if(!empty($object->siteName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('site-view', $object->site_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->siteName()}}</h6>
                                            <small>Site</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->job_date) || !empty($object->date_requested))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <h6 class="mb-0">Received date</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->job_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                        <div class="media-body">
                                            <h6 class="mb-0">Date Requested</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->date_requested)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                    </div>

                                @endif



                                @if (!empty($object->description))
                                    <div class="col-xl-12 col-lg-12 mb-1">

                                        <h6 class="mb-0">Description</h6>
                                        <p>{{ $object->description }}</p>
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <notes
                                :notes="processedNotes"
                                :parent-class="parent_class"
                                :parent-id="parent_id"
                                save-route="{{ '/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                delete-route="{{ '/'.$routePrefixPlural.'/delete-note'}}"
                            ></notes>

                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-5 col-lg-5 col-md-5">

                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <deliveries-list
                                :delivery-options="deliveryOptions"
                                :delivery-ids="deliveryIds"
                                :delivery-addresses="deliveryAddresses"
                                view-route="{{ route('delivery-view', '') }}"
                                create-route="{{ route('delivery-create', '') }}?purchaseOrderId={{$object->id}}"
                                title="Delivery Notes"
                            >

                            </deliveries-list>

                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <orders-list
                                :order-options="orderOptions"
                                :order-ids="orderIds"
                                :orders-by="ordersBy"
                                view-route="{{ route('order-view', '') }}"
                                edit-route="{{ route('order-edit', '') }}"
                                create-route="{{ route('order-create', '') }}?purchaseOrderId={{$object->id}}"
                                title="Supplier Orders"
                            ></orders-list>

                        </div>
                    </div>
                </div>

                @include('elements.serviceVisits', [
                   'createUrlParamName' => 'purchaseOrderId',
                   'accessorField' => 'serviceVisits',
                   'take' => 10,
               ])
                @include('elements.callOutJobs', [
                    'createUrlParamName' => 'purchaseOrderId',
                    'accessorField' => 'callOuts',
                    'take' => 10,
                ])

                {{-- Invoices --}}
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <invoices :invoices="invoices" parent-class="CustomerPurchaseOrder" parent-id="{{$object->id}}"></invoices>

                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-3 col-lg-3 col-md-3">
                @if($object->approval_required == 1 && $object->approved == 0)
                <b-card
                    tag="article"
                    style="width: 100%; flex: unset; background:#FFF475; border: solid 1px #DFD883;"
                    class="mb-2"
                >
                    <b-card-text>
                        <h6><i class="feather icon-alert-triangle"></i> Action Required</h6>
                        <p>PO locked due to price difference to the opportunity signed.
                            <br>Customer PO price - <strong>£{{ number_format($object->net_amount ?? 0, 2) }}</strong>
                            <br>Opportunity price - <strong>£{{ number_format($object->opportunity->total ?? 0, 2) }}</strong>
                            <br>Waiting for Approval by opportunity owner <strong>{{ $object->opportunity && $object->opportunity->creator ? $object->opportunity->creator->fullName : '' }}</strong>.</p>
                        @if($object->opportunity
                            && (
                                \Auth::user()->isSuperAdmin()
                                ||
                                (
                                    $object->opportunity->creator
                                    && $object->opportunity->creator->id == \Auth::user()->id
                                )
                            )
                        )
                        <b-button
                            variant="primary"
                            class="btn-icon"
                            href="{{ route('customer-purchase-order-approve', $object->id) }}"
                        >
                            Approve
                        </b-button>
                        @endif
                    </b-card-text>

                </b-card>
                @endif
                <div class="card plan-card border-primary">
                    <div class="card-header d-flex justify-content-between align-items-center pt-75">
                        <h5 class="mb-0"> Last Update </h5>
                        <small class="text-muted w-100">{{$object->updated_at}}</small>
                    </div>
                    <div class="card-body pt-75">
                        @php $updateByUser = $object->updater @endphp
                        @if (!empty($updateByUser))
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <h5 class="mb-50">
                                        Updated By
                                    </h5>

                                    <h6 class="mb-25"><i class="feather icon-user"></i> {{ $updateByUser->fullName }}</h6>
                                </div>
                            </div>
                        @endif

                        <div class="d-flex align-items-center mb-2">
                            <div class="">
                                <h5 class="mb-0">
                                    £{{ number_format(( (float) $object->net_amount), 2) }}
                                </h5>
                                <small>Net amount</small>
                            </div>
                        </div>
                    </div>



                </div>
            </div>
        </div>
    </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])

    <section class="data-list-view-header">
        <div class="add-new-data-sidebar" id="sidebar-service-visits">

            <div class="add-new-data js-sidebar-content w-75">

                <div class="div mt-2 px-2 d-flex new-data-title justify-content-between">
                    <div>
                        <h4>Service Visits</h4>
                    </div>
                    <div class="hide-data-sidebar">
                        <i class="feather icon-x"></i>
                    </div>
                </div>
                <div class="data-items pb-3">
                    <div class="data-fields px-2 mt-3">

                        <section id="data-list-view" class="data-list-view-header">

                            <!-- DataTable starts -->
                            <div class="table-responsive">
                                @include('jobs.serviceVisits.listingTable', ['serviceVisits' => $object->serviceVisits, 'createRoute' => route('service-visit-create')])
                            </div>
                            <!-- DataTable ends -->
                            {{-- @include('clients.sidebar-create') --}}
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <section class="data-list-view-header">
        <div class="add-new-data-sidebar" id="sidebar-call-outs">

            <div class="add-new-data js-sidebar-content w-75">

                <div class="div mt-2 px-2 d-flex new-data-title justify-content-between">
                    <div>
                        <h4>Call outs & Repairs</h4>
                    </div>
                    <div class="hide-data-sidebar">
                        <i class="feather icon-x"></i>
                    </div>
                </div>
                <div class="data-items pb-3">
                    <div class="data-fields px-2 mt-3">
                        <section id="data-list-view" class="data-list-view-header">

                            <!-- DataTable starts -->
                            <div class="table-responsive">
                                @include('jobs.callOuts.listingTable', ['callOuts' => $object->callOuts, 'createRoute' => route('call-out-create')])
                            </div>
                            <!-- DataTable ends -->
                            {{-- @include('clients.sidebar-create') --}}
                        </section>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@section('vendor-script')


    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.deliveryOptions = {!! json_encode($object->deliveries()->orderBy('created_at', 'desc')->get()) !!};
        window.pageData.orderOptions = {!! json_encode($object->orders()->orderBy('created_at', 'desc')->get()) !!};
        window.pageData.parent_class = "CustomerPurchaseOrder";
        window.pageData.parent_id = {{ $object->id }};
    </script>

    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>


@endsection
