@extends('layouts.contentLayoutMaster')

@section('title')
    Dashboard
@endsection

@section('content')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header">
                        <h4>Latest Opportunities Won</h4>
                    </div>
                    <div class="card-body">
                        @if ($wonOpportunities->count() == 0)
                            <p>No opportunity won recently.</p>
                        @else
                            @foreach($wonOpportunities as $opportunity)
                                @php $closedDate = $opportunity->closed_date ?  \Carbon\Carbon::parse($opportunity->closed_date) : null; @endphp
                                <div class="twitter-feed">
                                    <div class="d-flex justify-content-start align-items-center mb-1">
                                        <div class="avatar mr-50">
                                            <b-avatar variant="primary" text="{{$opportunity->createdByUser->first_name[0]}}{{$opportunity->createdByUser->last_name[0]}}"></b-avatar>
                                        </div>
                                        <div class="user-page-info">
                                            <small><p class="text-bold-600 mb-0">{{ $opportunity->createdByUser->fullName }}</p></small>
                                            @if(!empty($closedDate))
                                                <small>{{ $closedDate->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            @endif
                                            <div class="badge badge-secondary badge-pill badge-sm">
                                                {{ ucfirst($opportunity->status) }}
                                            </div>
                                        </div>
                                    </div>
                                    @if(!empty($opportunity->name))
                                        <p class="text-bold-600 mb-0"><a href="{{ route('opportunity-view', $opportunity->id) }}" >{{ $opportunity->name }}</a></p>
                                    @endif
                                    @if(!empty($closedDate))
                                        <p class="mb-0">{{ $closedDate->format(env('DEFAULT_DATE_FORMAT')) }}</p>
                                    @endif
                                    <hr>
                                </div>

                            @endforeach
                        @endif
                    </div>
                </div>

                <listing title="Pending Jobs"></listing>
            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header">
                        <h4>Contracts with Service Visits to be Booked</h4>
                    </div>
                    <div class="card-body">
                        @if ($contractsWithVisitsToBeBooked->count() == 0)
                            <p>No contract require visit to be booked soon.</p>
                        @else
                            @php
                                $contractsWithVisitsToBeBooked = $contractsWithVisitsToBeBooked->sortBy('expiry_date');
                            @endphp

                            @foreach($contractsWithVisitsToBeBooked as $contract)
                                @php $closedDate = null;  @endphp
                                <div class="twitter-feed">
                                    <div class="d-flex justify-content-start align-items-center mb-1">
                                        <div class="avatar mr-50">
                                            <b-avatar variant="primary" text="{{$contract->createdByUser->first_name[0]}}{{$contract->createdByUser->last_name[0]}}"></b-avatar>
                                        </div>
                                        <div class="user-page-info">
                                            <small><p class="text-bold-600 mb-0">{{ $contract->createdByUser->fullName }}</p></small>
                                            @if(!empty($closedDate))
                                                <small>{{ $closedDate->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            @endif
                                            <div class="badge badge-secondary badge-pill badge-sm">
                                                {{ ucfirst($contract->status) }}
                                            </div>
                                        </div>
                                    </div>
                                    @if(!empty($contract->name))
                                        <p class="text-bold-600 mb-0"><a href="{{ route('contract-view', $contract->id) }}" >{{ $contract->name }}</a></p>
                                    @endif
                                    @if(!empty($contract->clientName()))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('client-view', $contract->client_id) }}"
                                                    v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$contract->clientName()}}</h6>
                                                <small>Company</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($contract->siteName()))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('site-view', $contract->site_id) }}"
                                                    v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$contract->siteName()}}</h6>
                                                <small>Site</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($contract->start_date) || !empty($contract->expiry_date))

                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                            <div class="media-body">
                                                <h6 class="mb-0">Start Date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($contract->start_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                            <div class="media-body">
                                                <h6 class="mb-0">Expiry Date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($contract->expiry_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                        </div>

                                    @endif

                                    @if (!empty($contract->visits))
                                        <div class="col-xl-12 col-lg-12 mb-2">

                                            <h6 class="mb-25">Service Visits</h6>
                                            @foreach ($contract->visits as $visit)
                                                <span class="badge badge-secondary"> {{$visit->visit_month}} </span>
                                            @endforeach
                                        </div>
                                    @endif
                                    <a href="{{ route('service-visit-create') . '?contractId=' . $contract->id }}"
                                       class="btn @if($contract->closeToVisitDueDate) btn-danger @else btn-primary @endif mb-1 p-1 show-data-sidebar"
                                       target="_blank">
                                        <i class="feather icon-edit"></i>
                                        Book a Service Visit {{ $contract->closeToDueVisitDueDate }}
                                    </a>
                                    <hr>
                                </div>

                            @endforeach
                        @endif
                    </div>
                </div>
            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header">
                        <h4>Contracts Due for Review</h4>
                    </div>
                    <div class="card-body">
                        @if ($contractToReview->count() == 0)
                            <p>No contract to be reviewed soon.</p>
                        @else
                            @php
                                $contractToReview = $contractToReview->sortBy('expiry_date');
                            @endphp

                            @foreach($contractToReview as $contract)

                                <div class="twitter-feed">
                                    <div class="d-flex justify-content-start align-items-center mb-1">
                                        <div class="avatar mr-50">
                                            <b-avatar variant="primary" text="{{$contract->createdByUser->first_name[0]}}{{$contract->createdByUser->last_name[0]}}"></b-avatar>
                                        </div>
                                        <div class="user-page-info">
                                            <small><p class="text-bold-600 mb-0">{{ $contract->createdByUser->fullName }}</p></small>
                                            @if(!empty($closedDate))
                                                <small>{{ $closedDate->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            @endif
                                            <div class="badge badge-secondary badge-pill badge-sm">
                                                {{ ucfirst($contract->status) }}
                                            </div>
                                        </div>
                                    </div>
                                    @if(!empty($contract->name))
                                        <p class="text-bold-600 mb-0"><a href="{{ route('contract-view', $contract->id) }}" >{{ $contract->name }}</a></p>
                                    @endif
                                    @if(!empty($contract->clientName()))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('client-view', $contract->client_id) }}"
                                                    v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$contract->clientName()}}</h6>
                                                <small>Company</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($contract->siteName()))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('site-view', $contract->site_id) }}"
                                                    v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$contract->siteName()}}</h6>
                                                <small>Site</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($contract->start_date) || !empty($contract->expiry_date))

                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                            <div class="media-body">
                                                <h6 class="mb-0">Start Date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($contract->start_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                            <div class="media-body">
                                                <h6 class="mb-0">Expiry Date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($contract->expiry_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                        </div>

                                    @endif

                                    @if (!empty($contract->review_month))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <h6 class="mb-25">Review Month</h6>
                                            <span class="badge badge-secondary"> {{$contract->review_month}} </span>

                                        </div>
                                    @endif
                                    <b-button
                                        variant="primary"
                                        class="btn-icon"
                                        href="{{ route('contract-renew', $contract->id) }}"
                                    >
                                        Renew
                                    </b-button>
                                    <hr>

                                </div>

                            @endforeach
                        @endif
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection
