@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->delivery_number }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('deliveries'),
            'name' =>'Deliveries'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')
    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('delivery-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['delivery-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Delivery Details</h4>
                            <div class="pull-right">
                                @include('elements.document-note-buttons')
                            </div>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('delivery_number', 'Delivery Number *') !!}
                                            {!! Form::hidden('delivery_number', old('delivery_number'), ['id' => 'delivery_number']) !!}
                                            <strong>{{ $object->delivery_number }}</strong>
                                        </div>
                                        <div class="form-group">
                                            {!! Form::label('supplier_id', 'Supplier') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('supplier_id', $suppliers['options'], old('supplier_id'),
                                                        ['id' => 'supplier_id', 'class' => 'select2 form-control'] + $validationRules['supplier_id'])
                                                !!}
                                            </div>
                                        </div>
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id'),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control', 'disabled'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id'),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control', 'disabled'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status'),
                                                        ['id' => 'status', 'class' => 'select2 form-control'] + $validationRules['status'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="row">
                                            <div class="col-md-6 col-12">
                                                <div class="form-group">
                                                    {!! Form::label('expected_delivery_date', 'Expected Delivery Date') !!}
                                                    <div class="controls">
                                                        <input type="hidden" name="expected_delivery_date" :value="expected_delivery_date">
                                                        <date-picker
                                                            id="expected_delivery_date"
                                                            value-type="YYYY-MM-DD"
                                                            time-title-format="D MMM YYYY"
                                                            title-format="D MMM YYYY"
                                                            format="D MMM YYYY"
                                                            input-class="form-control"
                                                            type="date"
                                                            v-model="expected_delivery_date">
                                                        </date-picker>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-6 col-12">
                                                <div class="form-group">
                                                    {!! Form::label('delivery_date', 'Actual Delivery Date') !!}
                                                    <div class="controls">
                                                        <input type="hidden" name="delivery_date" :value="delivery_date">
                                                        <date-picker
                                                            id="delivery_date"
                                                            value-type="YYYY-MM-DD"
                                                            time-title-format="D MMM YYYY"
                                                            title-format="D MMM YYYY"
                                                            format="D MMM YYYY"
                                                            input-class="form-control"
                                                            type="date"
                                                            v-model="delivery_date">
                                                        </date-picker>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-12 col-12">
                                                <div class="form-group">
                                                    {!! Form::label('description', 'Description') !!}
                                                    <div class="controls">
                                                        {!!
                                                            Form::textarea('description', old('details'), [
                                                                'id' => 'description',
                                                                'class' => 'form-control',
                                                            ] + $validationRules['description'])
                                                        !!}
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('deliveries')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </section>

    </div>
    {{ Form::close() }}

    {{-- <div class="row">
        <div class="col-xl-5 col-lg-5 col-md-5">
            <div class="card">
                <div class="card-content">
                    <div class="card-body">

                        <addresses :addresses="addresses" :address-types="address_types" :parent-class="parent_class" :parent-id="parent_id" child-class="Delivery" child-id="{{$object->id}}"></addresses>

                    </div>
                </div>
            </div>
        </div>
    </div> --}}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')
@endsection

@section('vendor-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>


    <script>

        window.pageData = {!! json_encode($object) !!};

    </script>

    @include('panels.dropDownPickersScripts')
@endsection
