@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->delivery_number }}
@endsection

@section('vendor-style')
{{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

<?php //dd($object->supplier);?>

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('delivery-edit', $object->id) }}"
        ><i class="feather icon-edit"></i> Edit
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-12">
                <div class="card">
                    <div class="card-body pb-0">

                        <div class="pull-right">

                            <b-button
                                variant="primary"
                                class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                data-sidebar-content="sidebar-documents">
                                <i class="feather icon-paperclip"></i>
                                Documents
                            </b-button>


                            <b-button-group>
                                <b-button
                                    variant="primary"
                                    class="mb-1 p-1"
                                    href="{{  '/deliveries/download/'.$object->id }}"
                                >
                                    <i class="feather icon-download"></i>
                                    Customer Copy
                                </b-button>
                                <b-button
                                    variant="outline-primary"
                                    class="mb-1 p-1"
                                    @click="pdfPreview('{{'/deliveries/preview/'.$object->id }}', 'sidebar-pdf-preview')"
                                >
                                    <i class="feather icon-eye"></i>
                                </b-button>
                            </b-button-group>
                            @include("pdfTemplates.preview")
                        </div>

                    </div>
                </div>
            </div>
            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header object-toolbar">
                        <h4 class="card-title mb-25">Delivery Details</h4>
                        <span class="badge badge-info"> {{$object->status}} </span>
                        <span class="badge badge-info"> {{$object->type}} </span>
                    </div>

                    <div class="card-content">
                        <div class="card-body">


                            <div class="row">
                                @if(!empty($object->clientName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('client-view', $object->client_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->clientName()}}</h6>
                                            <small>Company</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->siteName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('site-view', $object->site_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->siteName()}}</h6>
                                            <small>Site</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->supplier))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('supplier-edit', $object->supplier->id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->supplier->name}}</h6>
                                            <small>Supplier</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->expected_delivery_date) || !empty($object->delivery_date))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <h6 class="mb-0">Expected Delivery</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->expected_delivery_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                        <div class="media-body">
                                            <h6 class="mb-0">Delivery Date</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->delivery_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                    </div>

                                @endif



                                @if (!empty($object->description))
                                    <div class="col-xl-12 col-lg-12 mb-1">

                                        <h6 class="mb-0">Description</h6>
                                        <p>{{ $object->description }}</p>
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <notes
                                :notes="processedNotes"
                                :parent-class="parent_class"
                                :parent-id="parent_id"
                                save-route="{{ '/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                delete-route="{{ '/'.$routePrefixPlural.'/delete-note'}}"
                            ></notes>

                        </div>
                    </div>
                </div>

            </div>
            <div class="col-xl-5 col-lg-5 col-md-5">
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <addresses :addresses="addresses" :address-types="address_types" :parent-class="parent_class" :parent-id="parent_id" child-class="Delivery" child-id="{{$object->id}}"></addresses>

                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-3 col-lg-3 col-md-3">
                <div class="card plan-card border-primary">
                    <div class="card-header d-flex justify-content-between align-items-center pt-75 pb-75">
                        <h5 class="mb-0"> Last Update </h5>
                        <small class="text-muted w-100">{{$object->updated_at}}</small>
                    </div>

                </div>

            </div>

            <div class="col-12">
                <supply-list
                    :data="data"
                    :id="id"
                    save-route="/deliveries/ajax/update-data"
                ></supply-list>
            </div>

        </div>
    </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])

@endsection

@section('vendor-script')


    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.parent_class = @if (!empty($object->site_id)) "Site" @else "Client" @endif;
        window.pageData.parent_id = @if (!empty($object->site_id)) "{{ $object->site_id }}" @else "{{ $object->client_id }}" @endif;
        window.pageData.child_class = "Delivery";
        window.pageData.child_id = {{ $object->id }};
        window.pageData.address_types = {!! json_encode($object->getAddressTypes()) !!};
    </script>

    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
        <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>


@endsection
