@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('inventories'),
            'name' =>'Inventories'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['inventory-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">


                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Item Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('code', 'Part Number *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('code', old('code'), [
                                                        'id' => 'code',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['code'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Description *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('unit', 'Unit') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('unit', old('unit'), [
                                                        'id' => 'unit',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['unit'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('supplier_ids', 'Supplier') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('supplier_ids[]', $suppliers['options'], old('supplier_ids', $object->suppliers()->withTrashed()->get()),
                                                        ['id' => 'supplier_ids', 'class' => 'select2 form-control', 'multiple' => 'multiple'] + $validationRules['supplier_ids'], $suppliers['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('internal_cost', 'Internal Cost * £') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('internal_cost', old('internal_cost'), [
                                                        'id' => 'internal_cost',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['internal_cost'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_charge', 'Client Charge * £') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('client_charge', old('client_charge'), [
                                                        'id' => 'client_charge',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['client_charge'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('updated_at', 'Updated At') !!}
                                            <div class="controls p-1">
                                                {{ $object->updated_at->format(env('DEFAULT_DATE_FORMAT')) }}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('inventories')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

@endsection
