@extends('layouts.contentLayoutMaster')

@section('title')
    Inventory items
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>'/',
            'name' =>'Dashboard'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('content')
    <section id="data-list-view" class="data-list-view-header">

        <!-- DataTable starts -->
        <div class="table-responsive">
            <table
                class="table data-list-view data-list-view-compact"
                data-create-route="{{route('inventory-create')}}"
                data-order='[[ 1, "asc" ]]'
                data-selectRow="false"
            >
                <thead>
                    <tr>
                        <th class="edit"></th>
                        <th width="10%">Part Number</th>
                        <th>Description</th>
                        <th>Unit</th>
                        <th>Internal Cost</th>
                        <th>Client Charge</th>
                    </tr>
                </thead>
                <tbody>
                @foreach($inventories as $inventory)
                    <tr data-id="{{ $inventory->id }}">
                        <td>
                            <div class="one-line">
                                <a href="{{route('inventory-edit', $inventory->id)}}">
                                    <button
                                        type="button"
                                        class="btn btn-icon btn-icon rounded-circle btn-flat-primary waves-effect waves-light"
                                        data-toggle="tooltip"
                                        data-placement="bottom"
                                        title="Edit"
                                        data-original-title="Edit"
                                    >
                                        <i class="feather icon-edit-2"></i>
                                    </button>
                                </a>
                                @if(\Auth::user()->isSuperAdmin())
                                    @include('elements.deleteButtonWithConfirmBox', [
                                        'confirmMessage' => 'Are you sure you want to delete this inventory item?',
                                        'successRoute' => route('inventory-delete', $inventory->id),
                                    ])
                                @endif
                            </div>
                        </td>
                        <td><a href="{{ route('inventory-edit', $inventory->id) }}">{{ $inventory->code }}</a></td>
                        <td><a href="{{ route('inventory-edit', $inventory->id) }}">{{ $inventory->name }}</a></td>
                        <td>{{ $inventory->unit }}</td>
                        <td>£{{ number_format(( (float) $inventory->internal_cost), 2) }}</td>
                        <td>£{{ number_format(( (float) $inventory->client_charge), 2) }}</td>
                    </tr>
                @endforeach
                </tbody>
            </table>
        </div>
        <!-- DataTable ends -->
        {{-- @include('clients.sidebar-create') --}}
    </section>
    <!-- Data list view end -->

@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/forms/select/select2.full.min.js') }}"></script>
@endsection

@section('page-script')
    {{-- Page js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/forms/select/form-select2.js') }}"></script>
@endsection
