@extends('layouts.contentLayoutMaster')

@section('title')
    Create an Invoice Record
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('invoices'),
            'name' =>'Invoices'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::open(['route' => ['invoice-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Invoice Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('invoice_number', 'Invoice Number *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('invoice_number', old('invoice_number'), [
                                                        'id' => 'invoice_number',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['invoice_number'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('invoice_date', 'Invoice Date *') !!}
                                            <div class="controls">
                                                <input type="hidden" name="invoice_date" :value="invoice_date">
                                                <date-picker
                                                    id="invoice_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="invoice_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('payment_due_date', 'Payment Due Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="payment_due_date" :value="payment_due_date">
                                                <date-picker
                                                    id="payment_due_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="payment_due_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('invoice_net_amount', 'Invoice Net Amount £') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('invoice_net_amount', old('invoice_net_amount'), [
                                                        'id' => 'invoice_net_amount',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['invoice_net_amount'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('invoice_tax_amount', 'Invoice Tax Amount £') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('invoice_tax_amount', old('invoice_tax_amount'), [
                                                        'id' => 'invoice_tax_amount',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['invoice_tax_amount'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('tax_code', 'Tax Code') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('tax_code', old('tax_code'), [
                                                        'id' => 'tax_code',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['tax_code'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('tax_rate', 'Tax Rate') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('tax_rate', old('tax_rate'), [
                                                        'id' => 'tax_rate',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['tax_rate'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('invoices')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

@endsection

@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
