@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('service-visits'),
            'name' =>'Service Visits'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')

    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('service-visit-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection


@section('content')

    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['service-visit-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">
                <div class="col-12">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Service Visit Details</h4>
                            <div class="pull-right">
                                @include('elements.document-note-buttons')
                            </div>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('job_number', 'Job Number') !!}
                                            <strong>{{ $jobNumber }}</strong>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Title *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('date', 'Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="visit_date" :value="visit_date">
                                                <date-picker
                                                    id="visit_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="visit_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('cost_type', 'Cost type *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('cost_type', $costTypes['options'], old('cost_type'),
                                                        ['id' => 'cost_type', 'class' => 'select2 form-control'] + $validationRules['cost_type'], $costTypes['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id'),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            <div class="controls">
                                                <b-form-group label="Parts Required?" v-slot="{ ariaDescribedby }">
                                                    <b-form-radio-group
                                                        v-model="parts_required"
                                                        name="parts_required"
                                                        :options="partsRequiredOptions"
                                                        :aria-describedby="ariaDescribedby"
                                                        buttons
                                                        button-variant="outline-primary"
                                                    ></b-form-radio-group>
                                                </b-form-group>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id'),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12" id="Opportunity">
                                        <div class="form-group @if($opportunities['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('opportunity_id', 'Opportunity *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('opportunity_id', $opportunities['options'], old('opportunity_id'),
                                                        ['id' => 'opportunity_id', 'class' => 'select2 form-control'] + $validationRules['opportunity_id'], $opportunities['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="contract">
                                        <div class="form-group @if($contracts['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('contract_id', 'Contract') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('contract_id', $contracts['options'], old('contract_id'),
                                                        ['id' => 'contract_id', 'class' => 'select2 form-control'] + $validationRules['contract_id'], $contracts['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12" id="status">
                                        <div class="form-group @if($customerPurchaseOrders['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('customer_purchase_order_id', 'Purchase Order *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('customer_purchase_order_id', $customerPurchaseOrders['options'], old('customer_purchase_order_id'),
                                                        ['id' => 'customer_purchase_order_id', 'class' => 'select2 form-control'] + $validationRules['customer_purchase_order_id'], $customerPurchaseOrders['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="status">
                                        <div class="form-group">
                                            {!! Form::label('status_id', 'Status *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status_id', $statuses['options'], old('status_id'),
                                                        ['id' => 'status_id', 'class' => 'select2 form-control'] + $validationRules['status_id'], $statuses['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12" id="operative">
                                        <div class="form-group">
                                            {!! Form::label('operative_ids', 'Operatives') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('operative_ids[]', $operatives['options'], old('operative_ids', $object->operatives),
                                                        ['id' => 'operative_ids', 'class' => 'select2 form-control'] + $validationRules['operative_ids'], $operatives['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12" id="operative">
                                        <div class="form-group">
                                            {!! Form::label('invoice_id', 'Invoice') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('invoice_id', $invoices['options'], old('invoice_id'),
                                                        ['id' => 'invoice_id', 'class' => 'select2 form-control'] + $validationRules['invoice_id'], $invoices['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('service-visits')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')

@endsection

@section('vendor-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
