@extends('layouts.contentLayoutMaster')
<?php
    $currentUser = \Illuminate\Support\Facades\Auth::user();
?>
@section('title')
    {{ $object->name }}
@endsection

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('service-visit-edit', $object->id) }}"
    ><i class="feather icon-edit"></i> Edit
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-12">
                <div class="card">
                    <div class="card-body pb-1">
                        <div class="pull-right">

                            @include('elements.document-note-buttons')
                            @if(\Auth::user()->isSuperAdmin() && $object->shouldReloadWorksheet())
                                {!! Form::model($object, ['route' => ['service-visit-reload-worksheet'], 'method' => 'post', 'class' => 'form form-vertical pull-right ml-25', 'novalidate', 'id' => 'worksheet-reload-form']) !!}
                                    <input type="hidden" name="worksheet_id" value="{{ $object->worksheetId }}">
                                    <input type="hidden" name="job_id" value="{{ $object->id }}">
                                    <input type="hidden" name="job_type" value="{{ get_class($object) }}">
                                    <b-button
                                        variant="warning"
                                        class=""
                                        @click="popConfirmBox" class="btn btn-icon btn-icon rounded-circle btn-warning mr-1 waves-effect waves-light"
                                        data-toggle="tooltip"data-placement="top" title="Reload Worksheet"
                                        data-original-title="Reload Worksheet"
                                        data-text="This action will wipe any submitted worksheet data! Are you sure you want to proceed?"
                                        data-confirm-text="Reload"
                                        data-cancel-text="Cancel"
                                        data-form-id-to-submit="worksheet-reload-form"
                                        data-success-route="{{ route('service-visit-reload-worksheet') }}"
                                    >
                                        <i class="feather icon-refresh-cw"></i>
                                    </b-button>
                                {{ Form::close() }}
                            @endif

                            @if($object->requiresApproval() && $currentUser && $currentUser->isSuperAdmin())
                                <b-button
                                    variant="success"
                                    class="show-data-sidebar"
                                    id="approve-button"
                                >
                                    <i class="feather icon-check-circle"></i>
                                    Approve
                                </b-button>
                            @endif
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header object-toolbar">
                        <h4 class="card-title mb-25">Job Details</h4>
                        <span class="badge badge-info"> {{$object->jobStatus->label}} </span>
                        @if($object->cost_type)
                            <span class="badge badge-info"> {{ $object->cost_type }} </span>
                        @endif
                        @if($object->requiresApproval())
                            <span class="badge badge-warning"> Approval Required </span>
                        @endif
                        @if($object->isApproved() )
                            <span class="badge badge-success"> Approved by {{ $object->getApproverName() }} </span>
                        @endif
                    </div>

                    <div class="card-content">
                        <div class="card-body">
                            <div class="row">
                                <div class="col-xl-12 col-lg-12 mb-1">
                                    <h6 class="mb-0">{{ $jobNumber }}</h6>
                                    <small>Job Number</small>
                                </div>

                                @if(!empty($object->clientName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('client-view', $object->client_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->clientName()}}</h6>
                                            <small>Company</small>
                                        </b-link>
                                    </div>
                                @endif

                                @if(!empty($object->siteName()))
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        <b-link href="{{ route('site-view', $object->site_id) }}"
                                            v-b-tooltip.hover.left title="View profile" >
                                            <h6 class="mb-0">{{$object->siteName()}}</h6>
                                            <small>Site</small>
                                        </b-link>
                                    </div>
                                @endif
                                <?php //dd($object->opportunity); ?>

                                @if(!empty($object->visit_date))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <h6 class="mb-0">Visit date</h6>
                                            <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->visit_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                        </div>
                                    </div>

                                @endif

                                @if(!empty($object->opportunity_id) && !empty($object->opportunity))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <b-link href="{{ route('opportunity-edit', $object->opportunity_id) }}"
                                                v-b-tooltip.hover.left title="View" >
                                                <h6 class="mb-0">
                                                    {{$object->opportunity->name}}
                                                    <span class="badge badge-secondary"> {{$object->opportunity->status}} </span>
                                                </h6>
                                                <small>Opportunity</small>
                                            </b-link>
                                        </div>
                                    </div>

                                @endif

                                @if(!empty($object->customer_purchase_order_id) && !empty($object->purchaseOrder))

                                    <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">

                                        <div class="media-body">
                                            <b-link href="{{ route('customer-purchase-order-view', $object->customer_purchase_order_id) }}"
                                                v-b-tooltip.hover.left title="View" >
                                                <h6 class="mb-0">
                                                    {{$object->purchaseOrder->name}}
                                                    <span class="badge badge-secondary"> {{$object->purchaseOrder->status}} </span>
                                                </h6>
                                                <small>Purchase Order</small>
                                            </b-link>
                                        </div>
                                    </div>

                                @endif



                                @if (!empty($object->description))
                                    <div class="col-xl-12 col-lg-12 mb-1">

                                        <h6 class="mb-0">Description</h6>
                                        <p>{{ $object->description }}</p>
                                    </div>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <notes
                                :notes="processedNotes"
                                :parent-class="child_class"
                                :parent-id="child_id"
                                save-route="{{ '/jobs/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                delete-route="{{ '/jobs/'.$routePrefixPlural.'/delete-note'}}"
                            ></notes>

                        </div>
                    </div>
                </div>

            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card plan-card border-primary">
                    <div class="card-header d-flex justify-content-between align-items-center pt-75">
                        <h5 class="mb-0"> Last Update </h5>
                        <small class="text-muted w-100">{{$object->updated_at}}</small>
                    </div>
                    <div class="card-body pt-75">
                        @php $updateByUser = $object->updater @endphp
                        @if (!empty($updateByUser))
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <h5 class="mb-50">
                                        Updated By
                                    </h5>

                                    <h6 class="mb-25"><i class="feather icon-user"></i> {{ $updateByUser->fullName }}</h6>
                                </div>
                            </div>
                        @endif

                        @if (!empty($object->operatives))
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <h5 class="mb-50">
                                        Operatives
                                    </h5>

                                    @if ($object->operatives->count() > 0)
                                            <b-avatar-group size="32px" class="">
                                                <i class="feather icon-users mt-75 mb-75 mr-1"></i>
                                                @foreach($object->operatives as $operative)
                                                    <b-avatar
                                                        v-b-tooltip.hover.bottom
                                                        variant="primary"
                                                        class="pull-up"
                                                        title="{{$operative->fullname}}"
                                                        text="{{$operative->first_name[0]}}{{$operative->last_name[0]}}"
                                                        variant="primary">
                                                    </b-avatar>
                                                @endforeach
                                            </b-avatar-group>
                                        @endif
                                </div>
                            </div>
                        @endif
                    </div>
                </div>
                {{-- Invoices --}}
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">

                            <invoices
                                :invoices="invoices"
                                :inventory-attached="inventoryAttached"
                                :parent-class="child_class"
                                :parent-id="child_id"
                            ></invoices>

                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <addresses
                                :addresses="addresses"
                                :address-types="address_types"
                                :parent-class="parent_class"
                                :parent-id="parent_id"
                                :child-class="child_class"
                                :child-id="child_id"
                            ></addresses>
                        </div>
                    </div>
                </div>
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <worksheet-group
                                :worksheet-data="worksheetData"
                                :worksheet-id="worksheetId"
                                :service-reports="serviceReports"
                                :service-report-structures="serviceReportStructures"
                                :worksheet-received-save-route="'/jobs/service-visits/ajax/{{$object->id}}/worksheet-received'"
                                :worksheet-received="worksheet_received"
                                :updater="updater"
                            ></worksheet-group>
                            @include("pdfTemplates.preview")
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-12 col-lg-12 col-md-12">
                <inventory-attached
                    :inventory-attached="inventoryAttached"
                    :parent-class="child_class"
                    :parent-id="child_id"
                ></inventory-attached>
            </div>
        </div>
    </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])

@endsection

@section('vendor-script')


    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};

        window.pageData.parent_class = @if (!empty($object->site_id)) "Site" @else "Client" @endif;;
        window.pageData.parent_id = @if (!empty($object->site_id)) "{{ $object->site_id }}" @else "{{ $object->client_id }}" @endif;
        window.pageData.child_class = "ServiceVisit";
        window.pageData.child_id = {{ $object->id }};
        window.pageData.address_types = {!! json_encode($object->getAddressTypes()) !!};
    </script>

    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>
    <script type="text/javascript">
        $( document ).ready(function() {
            $('#approve-button').click(function(){
                $(this).prop('disabled', true);
                $.post("{{ route('service-visit-approve', $object->id) }}", {"_token": csrf_token}, function(response) {
                    if(response === 'success') {
                        window.location.reload();
                    }
                });
            });
        });
    </script>

@endsection
