@extends('layouts.contentLayoutMaster')

@section('title')
	Create an Opportunity
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('opportunities'),
            'name' =>'Opportunities'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

	@include('elements.messages-error')

	{!! Form::open(['route' => ['opportunity-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
	@csrf
	<div class="form-body">

	<!-- // Basic multiple Column Form section start -->
		<section id="multiple-column-form">
			<div class="row match-height">

				<div class="col-12">


					<div class="card">
						<div class="card-header">
							<h4 class="card-title">Opportunity Details</h4>
						</div>
						<div class="card-content">
							<div class="card-body">
								<div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Title *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id', $selectedClientId),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    {{-- <div class="col-md-6 col-12 {{ !isset($selectedSiteId) ? 'picker' : '' }}" id="Site"> --}}
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {{-- {!! Form::label('site_id', 'Site') !!} --}}
                                            <label for="site_id">Site <b-spinner small class="display-hidden" /></label>

                                            <div class="controls">

                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id', $selectedSiteId),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('is_based_on_contract', 'Is opportunity based on an existing contract? *') !!}
                                            <div class="controls">
                                                <b-form-radio-group
                                                    id="is_based_on_contract"
                                                    v-model="is_based_on_contract"
                                                    name="is_based_on_contract"
                                                    buttons
                                                    button-variant="outline-primary"
                                                    data-validation-required-message="This field is required"
                                                >
                                                    <b-form-radio value="1">Yes</b-form-radio>
                                                    <b-form-radio value="0">No</b-form-radio>
                                                </b-form-radio-group>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6" v-if="is_based_on_contract == '1'">
                                        <div class="form-group">
                                            <label for="based_on_existing_contract_id">Which contract is it based on? *</label>
                                            <div class="controls">
                                                <input type="hidden" name="based_on_existing_contract_id" :value="based_on_existing_contract_id" />
                                                <v-select
                                                    v-model="based_on_existing_contract_id"
                                                    label="label"
                                                    :options="contracts"
                                                    id="based_on_existing_contract_id"
                                                    :reduce="(option) => option.value"
                                                    :disabled="is_based_on_contract != '1'"
                                                    data-validation-required-message="This field is required"
                                                />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group @if($contacts['options']->isEmpty()) disabled @endif">
                                            <label for="contact_id">Main Contact * <b-spinner small class="display-hidden" /></label>
                                            <div class="controls">
                                                {!!
                                                    Form::select('contact_id', $contacts['options'], old('contact_id'),
                                                        ['id' => 'contact_id', 'class' => 'select2 form-control'] + $validationRules['contact_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('open_date', 'Open Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="open_date" :value="open_date">
                                                <date-picker
                                                    id="open_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="open_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('estimated_close_date', 'Estimated Close Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="estimated_close_date" :value="estimated_close_date">
                                                <date-picker
                                                    id="estimated_close_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="estimated_close_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('closed_date', 'Closed Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="closed_date" :value="closed_date">
                                                <date-picker
                                                    id="closed_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="closed_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('total', 'Total (£)') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('total', old('total'), [
                                                        'id' => 'total',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['total'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6"></div>
{{--                                    <div class="col-md-6 col-12">--}}
{{--                                        <div class="form-group">--}}
{{--                                            {!! Form::label('weighted', 'Weighted') !!}--}}
{{--                                            <div class="controls">--}}
{{--                                                {!!--}}
{{--                                                    Form::text('weighted', old('weighted'), [--}}
{{--                                                        'id' => 'weighted',--}}
{{--                                                        'class' => 'form-control',--}}
{{--                                                    ] + $validationRules['weighted'])--}}
{{--                                                !!}--}}
{{--                                            </div>--}}
{{--                                        </div>--}}
{{--                                    </div>--}}

{{--                                    <div class="col-md-6 col-12">--}}
{{--                                        <div class="form-group">--}}
{{--                                            {!! Form::label('probability', 'Probability') !!}--}}
{{--                                            <div class="controls">--}}
{{--                                                {!!--}}
{{--                                                    Form::text('probability', old('Probability'), [--}}
{{--                                                        'id' => 'probability',--}}
{{--                                                        'class' => 'form-control',--}}
{{--                                                    ] + $validationRules['probability'])--}}
{{--                                                !!}--}}
{{--                                            </div>--}}
{{--                                        </div>--}}
{{--                                    </div>--}}

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status', app('request')->input('status') != null ? app('request')->input('status') : null),
                                                    [
                                                        'id' => 'status',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['status'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('reason', 'Reason') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('reason', old('reason'), [
                                                        'id' => 'reason',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['reason'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('process', 'Process *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('process', $processes['options'], old('process', app('request')->input('process') != null ? app('request')->input('process') : null),
                                                    [
                                                        'id' => 'process',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['process'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('stage', 'Stage *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('stage', $stages['options'], old('stage', app('request')->input('stage') != null ? app('request')->input('stage') : null),
                                                    [
                                                        'id' => 'stage',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['stage'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

								</div>
							</div>
						</div>
					</div>
				</div>
				<div class="col-12">
					<div class="card">
						<div class="card-content">
							<div class="card-body">
								<div class="row">
									<div class="col-12">
										<button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
										<a class="btn btn-flat-dark mb-1 p-1" href="{{route('sites')}}">Cancel</a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>

		</div>
	{{ Form::close() }}

@endsection

@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($opportunity) !!};
        window.pageData.contracts = {!! json_encode($contracts) !!};
    </script>
    @include('panels.dropDownPickersScripts')
@endsection
