@extends('layouts.contentLayoutMaster')

@section('title')
    {{$object->name}}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('opportunities'),
            'name' =>'Opportunities'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')
    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('opportunity-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['opportunity-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}

        @csrf

        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">


                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Opportunity Details</h4>
                            <div class="pull-right">
                                @include('elements.document-note-buttons')
                            </div>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Title *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id', $clientId),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12 picker" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id', $siteId),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('days_open', 'Days Open') !!} :
                                            <div class="controls">
                                                <strong>{{ App\Helpers\Helpers::calculateOpportunityDaysOpen($object) }}</strong> days
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('is_based_on_contract', 'Is opportunity based on an existing contract? *') !!}
                                            <div class="controls">
                                                <b-form-radio-group
                                                    id="is_based_on_contract"
                                                    v-model="is_based_on_contract"
                                                    name="is_based_on_contract"
                                                    buttons
                                                    button-variant="outline-primary"
                                                    data-validation-required-message="This field is required"
                                                >
                                                    <b-form-radio value="1">Yes</b-form-radio>
                                                    <b-form-radio value="0">No</b-form-radio>
                                                </b-form-radio-group>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6" v-if="is_based_on_contract == '1'">
                                        <div class="form-group">
                                            <label for="based_on_existing_contract_id">Which contract is it based on? *</label>
                                            <div class="controls">
                                                <input type="hidden" name="based_on_existing_contract_id" :value="based_on_existing_contract_id" />
                                                <v-select
                                                    v-model="based_on_existing_contract_id"
                                                    label="label"
                                                    :options="contracts"
                                                    id="based_on_existing_contract_id"
                                                    :reduce="(option) => option.value"
                                                    :disabled="is_based_on_contract != '1'"
                                                    data-validation-required-message="This field is required"
                                                />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            <label for="contact_id">Main Contact * <b-spinner small class="display-hidden" /></label>
                                            <div class="controls">
                                                {!!
                                                    Form::select('contact_id', $contacts['options'], old('contact_id', $object->contact_id),
                                                        ['id' => 'contact_id', 'class' => 'select2 form-control'] + $validationRules['contact_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('open_date', 'Open Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="open_date" :value="open_date">
                                                <date-picker
                                                    id="open_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="open_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('estimated_close_date', 'Estimated Close Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="estimated_close_date" :value="estimated_close_date">
                                                <date-picker
                                                    id="estimated_close_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="estimated_close_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('closed_date', 'Closed Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="closed_date" :value="closed_date">
                                                <date-picker
                                                    id="closed_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="closed_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('total', 'Total (£)') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('total', old('total'), [
                                                        'id' => 'total',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['total'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6"></div>
{{--                                    <div class="col-md-6 col-12">--}}
{{--                                        <div class="form-group">--}}
{{--                                            {!! Form::label('weighted', 'Weighted') !!}--}}
{{--                                            <div class="controls">--}}
{{--                                                {!!--}}
{{--                                                    Form::text('weighted', old('weighted'), [--}}
{{--                                                        'id' => 'weighted',--}}
{{--                                                        'class' => 'form-control',--}}
{{--                                                    ] + $validationRules['weighted'])--}}
{{--                                                !!}--}}
{{--                                            </div>--}}
{{--                                        </div>--}}
{{--                                    </div>--}}

{{--                                    <div class="col-md-6 col-12">--}}
{{--                                        <div class="form-group">--}}
{{--                                            {!! Form::label('probability', 'Probability') !!}--}}
{{--                                            <div class="controls">--}}
{{--                                                {!!--}}
{{--                                                    Form::text('probability', old('Probability'), [--}}
{{--                                                        'id' => 'probability',--}}
{{--                                                        'class' => 'form-control',--}}
{{--                                                    ] + $validationRules['probability'])--}}
{{--                                                !!}--}}
{{--                                            </div>--}}
{{--                                        </div>--}}
{{--                                    </div>--}}

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status', app('request')->input('status') != null ? app('request')->input('status') : null),
                                                    [
                                                        'id' => 'status',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['status'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('reason', 'Reason') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('reason', old('reason'), [
                                                        'id' => 'reason',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['reason'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('process', 'Process *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('process', $processes['options'], old('process', app('request')->input('process') != null ? app('request')->input('process') : null),
                                                    [
                                                        'id' => 'process',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['process'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('stage', 'Stage *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('stage', $stages['options'], old('stage', app('request')->input('stage') != null ? app('request')->input('stage') : null),
                                                    [
                                                        'id' => 'stage',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['stage'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('finalised_quote_id', 'Finalised Quote') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('finalised_quote_id', $lockedQuotes['options'], old('finalised_quote_id', $object->finalised_quote_id),
                                                        ['id' => 'finalised_quote_id', 'class' => 'select2 form-control'] + $validationRules['finalised_quote_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('opportunities')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    {{ Form::close() }}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')

    <div class="content-header row">
        <div class="content-header-left col-md-9 col-12 mb-2">
            <div class="row breadcrumbs-top">
                <div class="col-12">
                    <h2 class="content-header-title float-left mb-0">Quotes</h2>
                </div>
            </div>
        </div>
    </div>

    <section id="data-list-view" class="data-list-view-header">

        <!-- DataTable starts -->
        <div class="table-responsive">
            @include('quotes.listingTable', ['createRoute' => route('quote-create') . '?opportunityId=' . $object->id, 'fetchUrl' => route('opportunity-ajax-fetch-quotes')])
        </div>
        <!-- DataTable ends -->
        {{-- @include('clients.sidebar-create') --}}
    </section>
    @include("pdfTemplates.preview", ['title' => 'Quote'])

@endsection


@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>

@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.contracts = {!! json_encode($contracts) !!};
    </script>
    @include('panels.dropDownPickersScripts')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/ajaxIndexTable.js') }}"></script>
@endsection
