@extends('layouts.contentLayoutMaster')

@section('title')
    {{$object->name}}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('clients'),
            'name' =>'Companies'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('opportunity-edit', $object->id) }}"
        ><i class="feather icon-edit"></i> Edit
    </b-button>

@endsection


@section('content')
    @include('elements.messages-error')

        <section id="multiple-column-form">
            <div class="row match-height">
                <div class="col-12">
                    <div class="card">
                        <div class="card-body pb-0">

                            <div class="pull-right">

                                <button
                                    type="button"
                                    class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                    data-sidebar-content="sidebar-documents">
                                    <i class="feather icon-paperclip"></i>
                                    Documents
                                </button>

                            </div>

                        </div>
                    </div>
                </div>

                <div class="col-xl-4 col-lg-4 col-md-4">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title mb-25">Opportunity Details</h4>
                            <span class="badge badge-info"> {{$object->status}} </span>
                        </div>

                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-xl-12 col-lg-12 mb-1">
                                        @php
                                            $days_open = App\Helpers\Helpers::calculateOpportunityDaysOpen($object);
                                        @endphp
                                        @if(!empty($days_open))
                                            <span class="badge badge-secondary"> Opened for <b>{{$days_open}} @if($days_open > 1) days @else day @endif </b></span>
                                        @else
                                            <span class="badge badge-secondary"> Opened today </span>
                                        @endif
                                    </div>
                                    @if(!empty($object->client()))

                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('client-view', $object->client()->id) }}"
                                                v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$object->client()->company_name}}</h6>
                                                <small>Company</small>
                                            </b-link>
                                        </div>
                                    @endif

                                    @if(!empty($object->site()))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('site-view', $object->site()->id) }}"
                                                v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$object->site()->name}}</h6>
                                                <small>Site</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    <hr class="w-100">

                                    <div class="col-xl-12 col-lg-12 media d-flex justify-content-between">

                                        @if(!empty($object->open_date))
                                            <div class="media-body">
                                                <h6 class="mb-0">Open date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->open_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                        @endif
                                        @if(!empty($object->closed_date))
                                            <div class="media-body">
                                                <h6 class="mb-0">Close date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->closed_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                        @endif
                                        @if(!empty($object->estimated_close_date))
                                            <div class="media-body">
                                                <h6 class="mb-0">Estimated date</h6>
                                                <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->estimated_close_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                            </div>
                                        @endif

                                    </div>

                                    <hr class="w-100">

                                    @if (!empty($object->weighted))
                                        <div class="col-xl-12 col-lg-12">

                                            <h6 class="mb-0">Weighted</h6>
                                            <p>{{ $object->weighted }}</p>
                                        </div>
                                    @endif
                                    @if (!empty($object->probability))
                                        <div class="col-xl-12 col-lg-12">

                                            <h6 class="mb-0">Probability</h6>
                                            <p>{{ $object->probability }}</p>
                                        </div>
                                    @endif
                                    @if (!empty($object->reason))
                                        <div class="col-xl-12 col-lg-12">

                                            <h6 class="mb-0">Reason</h6>
                                            <p>{{ $object->reason }}</p>
                                        </div>
                                    @endif

                                    @if (!empty($object->weighted) || !empty($object->probability) || !empty($object->reason))

                                    <hr class="w-100">

                                        @if (!empty($object->weighted))
                                            <div class="col-xl-12 col-lg-12">

                                                <h6 class="mb-0">Weighted</h6>
                                                <p>{{ $object->weighted }}</p>
                                            </div>
                                        @endif
                                        @if (!empty($object->probability))
                                            <div class="col-xl-12 col-lg-12">

                                                <h6 class="mb-0">Probability</h6>
                                                <p>{{ $object->probability }}</p>
                                            </div>
                                        @endif
                                        @if (!empty($object->reason))
                                            <div class="col-xl-12 col-lg-12">

                                                <h6 class="mb-0">Reason</h6>
                                                <p>{{ $object->reason }}</p>
                                            </div>
                                        @endif
                                    @endif
                                    @if($object->is_based_on_contract && $object->based_on_existing_contract_id)
                                        <hr class="w-100">
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('contract-view', $object->basedOnContract->id) }}" target="_blank"
                                                    v-b-tooltip.hover.left title="View contract" >
                                                <h6 class="mb-0">{{$object->basedOnContract->name}}
                                                </h6>
                                                <small>Based on contract</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($object->finalisedQuote))

                                        <hr class="w-100">
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('quote-preview', $object->finalisedQuote->id) }}" target="_blank"
                                                v-b-tooltip.hover.left title="Preview quote" >
                                                <h6 class="mb-0">{{$object->finalisedQuote->name}}
                                                    {{-- <span class="badge badge-secondary"> {{$object->finalisedQuote->template->name}} </span> --}}
                                                </h6>
                                                <small>Finalised Quote</small>
                                            </b-link>
                                        </div>
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <send-email
                                                :current-user="currentUser"
                                                :contacts="contacts"
                                                :contacts-selected="contactsSelected"
                                                :id="id"
                                                :title="`Quote`"
                                                :attachment="true"
                                                send-route="{{ route('opportunity-send-quote', $object->id) }}"
                                                :notes="processedNotes"
                                                :cc-emails="ccEmails"
                                                :cc-emails-selected="ccEmailsSelected"
                                            ></send-email>

                                        </div>
                                    @endif
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <notes
                                    :notes="processedNotes"
                                    :parent-class="parent_class"
                                    :parent-id="parent_id"
                                    save-route="{{ '/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                    delete-route="{{ '/'.$routePrefixPlural.'/delete-note'}}"
                                ></notes>

                            </div>
                        </div>
                    </div>

                </div>
                <div class="col-xl-5 col-lg-5 col-md-5">
                    <div class="card card-developer-meetup">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">PO Received</h4>
                            <b-button
                                variant="primary"
                                class="btn-icon"
                                href="{{ route('customer-purchase-order-create') }}?opportunityId={{$object->id}}"
                                style="position: absolute;top: 9px;right: 10px;"
                            >
                                <i class="feather icon-plus">

                                </i>
                            </b-button>
                        </div>
                        <div class="card-body">
                            @foreach($object->purchaseOrders as $customerPurchaseOrder)
                                <div class="media d-flex justify-content-between">
                                    <div class="media-body">
                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">
                                            <div class="media-body">

                                                <h6 class="mb-0"><a target="_blank" href="{{ route('customer-purchase-order-view', ['id' => $customerPurchaseOrder->id]) }}">{{ $customerPurchaseOrder->name }}</a></h6>
                                                @if ($customerPurchaseOrder->description)
                                                    <h6 class="mb-0 mt-50">{{ $customerPurchaseOrder->description }}</h6>
                                                @endif
                                                <span class="badge badge-info" style="position: absolute; top: 0; right: 0;"> {{$customerPurchaseOrder->status}} </span>
                                            </div>
                                        </div>
                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">
                                            @if(!empty($customerPurchaseOrder->job_date))
                                                <div class="media-body">
                                                    <h6 class="mb-0">Received date</h6>
                                                    <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($customerPurchaseOrder->job_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                                </div>
                                            @endif
                                            @if(!empty($customerPurchaseOrder->date_requested))
                                                <div class="media-body">
                                                    <h6 class="mb-0">Date Requested</h6>
                                                    <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($customerPurchaseOrder->date_requested)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                                </div>
                                            @endif
                                        </div>
                                        <div class="col-xl-12 col-lg-12 mb-1 media d-flex justify-content-between">
                                            @if($customerPurchaseOrder->opportunity)
                                                <div class="media-body">
                                                    <h6 class="mb-0">Opportunity</h6>
                                                    <small>{{ $customerPurchaseOrder->opportunity->name }}</small>
                                                </div>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <hr>
                            @endforeach
                        </div>
                    </div>

                </div>

                <div class="col-xl-3 col-lg-3 col-md-3">
                    <div class="card plan-card border-primary">
                        <div class="card-header d-flex justify-content-between align-items-center pt-75 pb-25">
                            <h5 class="mb-0"> Last Update </h5>
                            <small class="text-muted w-100">{{$object->updated_at}}</small>
                        </div>
                        <div class="card-body">
                            <div class="d-flex align-items-center">
                                @if(!empty($object->process))
                                    <div class="media-body mb-1">
                                        <h6 class="mb-0">Process <span class="badge badge-secondary"> {{$object->process}} </span></h6>

                                    </div>
                                @endif
                                @if(!empty($object->stage))
                                    <div class="media-body mb-1">
                                        <h6 class="mb-0">Stage <span class="badge badge-secondary"> {{$object->stage}} </span></h6>

                                    </div>
                                @endif
                            </div>
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <h5 class="mb-0">
                                        £{{ number_format(( (float) $object->total), 2) }}
                                    </h5>
                                    <small>Total</small>
                                </div>
                            </div>

                            @if (!empty($object->contact))
                                <div class="d-flex align-items-center mb-2">
                                    <div class="">
                                        <h5 class="mb-0">
                                            {{$object->contact->fullName}}
                                        </h5>
                                        <small>Main Contact</small>
                                    </div>
                                </div>
                            @endif

                            <b-button
                                block
                                variant="primary"
                                class="btn btn-primary text-center btn-block"
                                v-b-toggle.sidebar-quotes
                            ><i class="feather icon-edit"></i> Quote List
                            </b-button>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])


    <b-sidebar id="sidebar-quotes" bg-variant="white" title="Quotes" right shadow backdrop class="bg-white" width="85%">
        <div class="px-1 py-2">
            <div class="data-list-view-header">
                <div class="table-responsive">
                    @include('quotes.listingTable', ['createRoute' => route('quote-create') . '?opportunityId=' . $object->id, 'fetchUrl' => route('opportunity-ajax-fetch-quotes')])
                </div>
            </div>
        </div>
    </b-sidebar>
    @include("pdfTemplates.preview", ['title' => 'Quote'])


@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/charts/apexcharts.min.js') }}"></script>
    {{-- <script src="https://cdn.jsdelivr.net/npm/apexcharts"></script> --}}

@endsection

@section('page-script')
    <script>

        @php
            $authUser = Auth::user();
            $contact = new \App\Models\Contact();

            if ($authUser) {
                $contact->email = $authUser->email;
                $contact->first_name = $authUser->first_name;
                $contact->last_name = $authUser->last_name;
            }
        @endphp

        window.pageData = {!! json_encode($object) !!};
        window.pageData.currentUser = {!! json_encode(Auth::user()) !!};
        window.pageData.contacts = {!! !empty($object->finalisedQuote) ? json_encode($object->client()->allContacts) : json_encode([]) !!};
        window.pageData.contactsSelected = {!! !empty($object->finalisedQuote) ? json_encode($object->getContactEmail(true)) : json_encode([]) !!};
        window.pageData.parent_class = "Opportunity";
        window.pageData.parent_id = {{ $object->id }};
        window.pageData.ccEmails = {!! json_encode([$contact]) !!};
        window.pageData.ccEmailsSelected = {!! json_encode([$contact->email]) !!};

    </script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/pages/app-invoice.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/ajaxIndexTable.js') }}"></script>
@endsection
