@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->order_number }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('orders'),
            'name' =>'Orders'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')
    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('order-view', $object->id) }}"
        ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['order-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title">Order Details</h4>
                            <div class="pull-right">
                                @include('elements.document-note-buttons')
                            </div>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('order_number', 'Order Number: ') !!}
                                            {!! Form::hidden('order_number', old('order_number'), ['id' => 'order_number']) !!}
                                            <strong>{{ $object->order_number }}</strong>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('supplier_id', 'Supplier') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('supplier_id', $suppliers['options'], old('supplier_id'),
                                                        ['id' => 'supplier_id', 'class' => 'select2 form-control'] + $validationRules['supplier_id'], $suppliers['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id'),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group @if($sites['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id'),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('order_date', 'Order Date *') !!}
                                            <div class="controls">
                                                <input type="hidden" name="order_date" :value="order_date">
                                                <date-picker
                                                    id="order_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="order_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('order_by', 'Ordered By *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('order_by', $users['options'], old('order_by'),
                                                        ['id' => 'order_by', 'class' => 'select2 form-control'] + $validationRules['order_by'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('requested_by', 'Requested By *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('requested_by', $users['options'], old('requested_by'),
                                                        ['id' => 'requested_by', 'class' => 'select2 form-control'] + $validationRules['requested_by'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('details', 'Details') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::textarea('details', old('details'), [
                                                        'id' => 'details',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['details'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status'),
                                                        ['id' => 'status', 'class' => 'select2 form-control'] + $validationRules['status'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>





                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('estimated_delivery_date', 'Estimated Delivery Date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="estimated_delivery_date" :value="estimated_delivery_date">
                                                <date-picker
                                                    id="estimated_delivery_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="estimated_delivery_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('date_received', 'Date Received') !!}
                                            <div class="controls">
                                                <input type="hidden" name="date_received" :value="date_received">
                                                <date-picker
                                                    id="date_received"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="date_received">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('credit_note_received', 'Credit Note Received') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('credit_note_received', old('credit_note_received'), [
                                                        'id' => 'credit_note_received',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['credit_note_received'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-md-6 col-12">
                                        <div class="form-group @if($returns['options']->isEmpty()) disabled @endif">
                                            {!! Form::label('return_ids', 'Returns') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('return_ids[]', $returns['options'], old('return_ids', $object->returns()->withTrashed()->get()),
                                                        ['id' => 'return_ids', 'class' => 'select2 form-control', 'multiple' => 'multiple'] + $validationRules['return_ids'], $returns['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-6 col-12">

                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <deliveries-list :delivery-options="deliveryOptions" :delivery-ids="deliveryIds" :delivery-addresses="deliveryAddresses" view-route="{{ route('delivery-view', '') }}" create-route="{{ route('delivery-create', '') }}?orderId={{$object->id}}"></deliveries-list>

                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('orders')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')
@endsection

@section('vendor-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
