@extends('layouts.contentLayoutMaster')

@section('title')
    {{$object->order_number}}

@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('clients'),
            'name' =>'Companies'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/validation/form-validation.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('order-edit', $object->id) }}"
        ><i class="feather icon-edit"></i> Edit
    </b-button>

@endsection


@section('content')
    @include('elements.messages-error')

        <section id="multiple-column-form">
            <div class="row match-height">
                <div class="col-12">
                    <div class="card">
                        <div class="card-body pb-0">

                            <div class="pull-right">

                                <button
                                    type="button"
                                    class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                    data-sidebar-content="sidebar-documents">
                                    <i class="feather icon-paperclip"></i>
                                    Documents
                                </button>

                                <b-button-group>
                                    <b-button
                                        variant="primary"
                                        class="mb-1 p-1"
                                        href="{{  '/orders/download/'.$object->id }}"
                                    >
                                        <i class="feather icon-download"></i>
                                        Supplier Copy
                                    </b-button>
                                    <b-button
                                        variant="outline-primary"
                                        class="mb-1 p-1"
                                        @click="pdfPreview('{{'/orders/preview/'.$object->id }}', 'sidebar-pdf-preview')"
                                    >
                                        <i class="feather icon-eye"></i>
                                    </b-button>
                                </b-button-group>
                                @include("pdfTemplates.preview")

                            </div>

                        </div>
                    </div>
                </div>

                <div class="col-xl-4 col-lg-4 col-md-4">
                    <div class="card">
                        <div class="card-header object-toolbar">
                            <h4 class="card-title mb-25">Order Details</h4>
                        </div>

                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">

                                    @if(!empty($object->client_id))



                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('client-view', $object->client_id) }}"
                                                v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$object->clientName()}}</h6>
                                                <small>Company</small>
                                            </b-link>
                                        </div>
                                    @endif

                                    @if(!empty($object->site_id))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('site-view', $object->site_id) }}"
                                                v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$object->siteName()}}</h6>
                                                <small>Site</small>
                                            </b-link>
                                        </div>
                                    @endif
                                    @if(!empty($object->supplier_id))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <b-link href="{{ route('supplier-view', $object->supplier_id) }}"
                                                v-b-tooltip.hover.left title="View profile" >
                                                <h6 class="mb-0">{{$object->supplierName()}}</h6>
                                                <small>Supplier</small>
                                            </b-link>
                                        </div>
                                    @endif

                                    @if(!empty($object->order_date) || !empty($object->estimated_delivery_date) || !empty($object->date_received))

                                    <hr class="w-100">

                                        <div class="col-xl-12 col-lg-12 media d-flex justify-content-between">
                                            @if(!empty($object->order_date))
                                                <div class="media-body">
                                                    <h6 class="mb-0">Ordered</h6>
                                                    <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->order_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                                </div>
                                            @endif
                                            @if(!empty($object->estimated_delivery_date))
                                                <div class="media-body">
                                                    <h6 class="mb-0">Estimated</h6>
                                                    <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->estimated_delivery_date)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                                </div>
                                            @endif
                                            @if(!empty($object->date_received))
                                                <div class="media-body">
                                                    <h6 class="mb-0">Received</h6>
                                                    <i class="feather icon-calendar"></i> <small>{{ \Carbon\Carbon::parse($object->date_received)->format(env('DEFAULT_DATE_FORMAT')) }}</small>
                                                </div>
                                            @endif
                                        </div>
                                    <hr class="w-100">
                                    @endif

                                    @if(!empty($object->details))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <div class="media-body">
                                                <h6 class="mb-0">Details</h6>
                                                {{$object->details}}
                                            </div>
                                        </div>
                                    @endif
                                    @if(!empty($object->details))
                                        <div class="col-xl-12 col-lg-12 mb-1">
                                            <div class="media-body">
                                                <h6 class="mb-0">Credit Note Received</h6>
                                                {{$object->credit_note_received}}
                                            </div>
                                        </div>
                                    @endif


                                    <div class="col-xl-12 col-lg-12 mt-1">
                                        <send-email
                                            :current-user="currentUser"
                                            :contacts="contacts"
                                            :id="id"
                                            title="Supplier PO"
                                            :attachment="true"
                                            send-route="{{ route('order-send', $object->id) }}"
                                            :cc-emails="ccEmails"
                                            :cc-emails-selected="ccEmailsSelected"
                                        ></send-email>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <notes
                                    :notes="processedNotes"
                                    :parent-class="parent_class"
                                    :parent-id="parent_id"
                                    save-route="{{ '/'.$routePrefixPlural.'/'.$object->id.'/add-note'}}"
                                    delete-route="{{ '/'.$routePrefixPlural.'/delete-note'}}"
                                ></notes>

                            </div>
                        </div>
                    </div>

                </div>

                <div class="col-xl-5 col-lg-5 col-md-5">

                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <deliveries-list :delivery-options="deliveryOptions" :delivery-ids="deliveryIds" :delivery-addresses="deliveryAddresses" view-route="{{ route('delivery-view', '') }}" create-route="{{ route('delivery-create', '') }}?orderId={{$object->id}}"></deliveries-list>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="col-xl-3 col-lg-3 col-md-3">
                    <div class="card plan-card border-primary">
                        <div class="card-header d-flex justify-content-between align-items-center pt-75 pb-25">
                            <h5 class="mb-0"> Last Update </h5>
                            <span class="badge badge-info"> {{$object->status}} </span>
                            <small class="text-muted w-100">{{$object->updated_at}}</small>
                        </div>
                        <div class="card-body">
                            <div class="d-flex align-items-center">
                                @if(!empty($object->process))
                                    <div class="media-body mb-1">
                                        <h6 class="mb-0">Process <span class="badge badge-secondary"> {{$object->process}} </span></h6>

                                    </div>
                                @endif
                                @if(!empty($object->stage))
                                    <div class="media-body mb-1">
                                        <h6 class="mb-0">Stage <span class="badge badge-secondary"> {{$object->stage}} </span></h6>

                                    </div>
                                @endif
                            </div>
                            <div class="d-flex align-items-center mb-2">
                                <div class="">
                                    <small>Last update by</small>
                                    <h5 class="mb-0">
                                        {{\App\Models\User::find($object->updated_by) ? \App\Models\User::find($object->updated_by)->fullName : '' }}
                                    </h5>

                                </div>
                            </div>

                            @if (!empty($object->order_by))
                                <div class="d-flex align-items-center mb-2">
                                    <div class="">
                                        <small>Created by</small>
                                        <h5 class="mb-0">
                                            {{\App\Models\User::find($object->order_by) ? \App\Models\User::find($object->order_by)->fullName : ''}}
                                        </h5>

                                    </div>
                                </div>
                            @endif

                        </div>
                    </div>
                </div>

                <div class="col-12">
                    <inventory-attached
                        :inventory-attached="inventoryAttached"
                        :parent-class="parent_class"
                        :parent-id="parent_id"
                        :customer="false"
                    ></inventory-attached>
                </div>
            </div>
        </section>

    @include('elements.documents-side-panel', [
        'types' => [
            [
                'id' => 'sidebar-documents',
                'title' => 'General Documents',
                'uploadRouteName' => $routePrefixSingular . '-document-upload',
                'documents' => $object->getDocumentsByType()
            ]
        ]
    ])
    @include('elements.notes-side-panel')

@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/charts/apexcharts.min.js') }}"></script>
    {{-- <script src="https://cdn.jsdelivr.net/npm/apexcharts"></script> --}}

@endsection

@section('page-script')
    <script>

        @php
            $authUser = Auth::user();
            $contact = new \App\Models\Contact();

            if ($authUser) {
                $contact->email = $authUser->email;
                $contact->first_name = $authUser->first_name;
                $contact->last_name = $authUser->last_name;
            }
        @endphp

        window.pageData = {!! json_encode($object) !!};
        window.pageData.currentUser = {!! json_encode(Auth::user()) !!};
        window.pageData.contacts = {!! $object->supplier ? json_encode($object->supplier->contacts) : json_encode(collect([])) !!};
        window.pageData.parent_class = "Order";
        window.pageData.parent_id = {{ $object->id }};
        window.pageData.ccEmails = {!! json_encode([$contact]) !!};
        window.pageData.ccEmailsSelected = {!! json_encode([$contact->email]) !!};

    </script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/extensions/dropzone.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/navs/navs.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/pages/app-invoice.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/ajaxIndexTable.js') }}"></script>
@endsection
