<script type="text/javascript">
    $( document ).ready(function() {

        let clientsDropDown = $('#client_id');
        let sitesDropDown = $('#site_id');
        let contactsDropDown = $('#contact_id');
        let opportunityDropDown = $('#opportunity_id');
        let deliveryDropDown = $('#delivery_ids');
        let orderDropDown = $('#order_ids');
        let returnDropDown = $('#return_ids');
        let customerPurchaseOrderDropDown = $('#customer_purchase_order_id');
        let deliveryAddressDropDown = $('#address_id');
        let contractDropDown = $('#contract_id');


        function updateParent(parentClass, parentId){
            // update Parent only if Child is present
            if ( window.pageData.child_id){
                VueEvent.$emit('updateParent', parentClass, parentId);
            }
        }
        if ( sitesDropDown.length > 0 && sitesDropDown.val()){
            updateParent('Site', sitesDropDown.val());
        }
        else if ( clientsDropDown.length > 0 && clientsDropDown.val()){
            updateParent('Client', clientsDropDown.val());
        }


        function updateDropDownOptionsFromResponse(dropDown, response, multiSelect = false) {

            if(Object.keys(response).length > 0){
                dropDown.closest('.form-group').removeClass('disabled');
                dropDown.empty();
                if (!multiSelect){
                    dropDown.append($("<option></option>").attr("value", '').text('Please Select'));
                }
                $.each(response, function(key,value) {
                    dropDown.append($("<option></option>")
                        .attr("value", key).text(value));
                });
            }
            else{
                dropDown.empty();
                dropDown.closest('.form-group').addClass('disabled');
                dropDown.append($("<option></option>").attr("value", '').text(''));
            }

        }

        function makeSelectData(dataArray, mapKey, mapValue){

            let selectData = {};

            let rArr = dataArray.map( obj => {
                let rObj = {};
                rObj[obj[mapKey]] = obj[mapValue];
                return rObj;
            });

            rArr.map((e)=>Object.assign(selectData, e));

            return selectData;

        }

        function disableElement(element){

            element.closest('.form-group').addClass('disabled');
        }

        clientsDropDown.change(function(){

            updateParent('Client', clientsDropDown.val());

            if (sitesDropDown.length > 0){
                disableElement(sitesDropDown);
                $.post( "/sites/fetch-by-client", { clientId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(sitesDropDown, response);
                });
            }

            if (contactsDropDown.length > 0){
                disableElement(contactsDropDown);
                $.post( "/contacts/fetch-by-client", { clientId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(contactsDropDown, response);
                });
            }

            if (opportunityDropDown.length > 0){
                disableElement(opportunityDropDown);
                $.post( "/opportunities/fetch-by-client", {clientId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(opportunityDropDown, response);
                });
            }

            if (orderDropDown.length > 0){
                disableElement(orderDropDown);
                $.post( "/orders/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(orderDropDown, makeSelectData(response, "id", "order_number"), true);
                    VueEvent.$emit('updateOrders', response);
                    VueEvent.$emit('updateSelectedOrders', []);
                });
            }

            if (returnDropDown.length > 0){
                disableElement(returnDropDown);
                $.post( "/returns/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(returnDropDown, makeSelectData(response, "id", "cwt_return_number"), true);
                });
            }

            if (deliveryDropDown.length > 0){
                disableElement(deliveryDropDown);
                $.post( "/deliveries/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(deliveryDropDown, makeSelectData(response, "id", "delivery_number"), true);
                    VueEvent.$emit('updateDeliveries', response);
                    VueEvent.$emit('updateSelectedDeliveries', []);
                });
            }

            if (customerPurchaseOrderDropDown.length > 0){
                disableElement(customerPurchaseOrderDropDown);
                $.post( "/customer-purchase-orders/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(customerPurchaseOrderDropDown, makeSelectData(response, "id", "name"));
                });
            }

            if (deliveryAddressDropDown.length > 0){
                disableElement(deliveryAddressDropDown);
                $.post( "/addresses/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(deliveryAddressDropDown, makeSelectData(response, "id", "fullAddress"));
                });
            }

            if (contractDropDown.length > 0){
                disableElement(contractDropDown);
                $.post( "/contracts/fetch", { companyId: clientsDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(contractDropDown, makeSelectData(response, "id", "name"));
                });
            }

        });

        sitesDropDown.change(function(){

            updateParent('Site', sitesDropDown.val());

            if (contactsDropDown.length > 0){
                disableElement(contactsDropDown);
                $.post( "/contacts/fetch-by-site", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(contactsDropDown, response);
                });
            }

            if(opportunityDropDown.length > 0){
                disableElement(opportunityDropDown);
                $.post( "/opportunities/fetch-by-site", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}', includeCompany: true }, function(response) {
                    updateDropDownOptionsFromResponse(opportunityDropDown, response);
                });
            }

            if (orderDropDown.length > 0){
                disableElement(orderDropDown);
                $.post( "/orders/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(orderDropDown, makeSelectData(response, "id", "order_number"), true);
                    VueEvent.$emit('updateOrders', response);
                    VueEvent.$emit('updateSelectedOrders', []);
                });
            }

            if (returnDropDown.length > 0){
                disableElement(returnDropDown);
                $.post( "/returns/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(returnDropDown, makeSelectData(response, "id", "cwt_return_number"), true);
                });
            }

            if(deliveryDropDown.length > 0){
                disableElement(deliveryDropDown);
                $.post( "/deliveries/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(deliveryDropDown, makeSelectData(response, "id", "delivery_number"), true);
                    VueEvent.$emit('updateDeliveries', response);
                    VueEvent.$emit('updateSelectedDeliveries', []);
                });
            }

            if (customerPurchaseOrderDropDown.length > 0){
                disableElement(customerPurchaseOrderDropDown);
                $.post( "/customer-purchase-order/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(customerPurchaseOrderDropDown, makeSelectData(response, "id", "name"));
                });
            }

            if (deliveryAddressDropDown.length > 0){
                disableElement(deliveryAddressDropDown);
                $.post( "/addresses/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(deliveryAddressDropDown, makeSelectData(response, "id", "fullAddress"));
                });
            }

            if (contractDropDown.length > 0){
                disableElement(contractDropDown);
                $.post( "/contracts/fetch", { siteId: sitesDropDown.val(), _token: '{{ csrf_token() }}' }, function(response) {
                    updateDropDownOptionsFromResponse(contractDropDown, makeSelectData(response, "id", "name"));
                });
            }


        });


        $("#delivery_ids.select2")
            .select2()
            .on("select2:select select2:unselect", e => {

                let select2Selected = document.getElementById('delivery_ids').selectedOptions;
                let selectedDeliveries = Array.from(select2Selected).map(({ value }) => parseInt(value));

                VueEvent.$emit('updateSelectedDeliveries', selectedDeliveries);

            });

        $("#order_ids.select2")
            .select2()
            .on("select2:select select2:unselect", e => {

                let select2Selected = document.getElementById('order_ids').selectedOptions;
                let selectedOrders = Array.from(select2Selected).map(({ value }) => parseInt(value));

                VueEvent.$emit('updateSelectedOrders', selectedOrders);

            });
    });
</script>
