@extends('layouts.contentLayoutMaster')

@section('title')
    Edit Quote Document: @{{name}}
@endsection

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/pickers/flatpickr/flatpickr.min.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/forms/pickers/form-flat-pickr.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/app-invoice.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection


@section('content')
    @include('elements.messages-error')

    {!! Form::model($object, ['route' => ['quote-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate', 'id' => 'quote-form']) !!}

    @csrf

    <input type="hidden" name="name" v-model="name">
    <input type="hidden" name="author_id" v-model="author_id">
    <input type="hidden" name="internal_ref" v-model="internal_ref">

    <section class="invoice-edit-wrapper">
        <div class="row invoice-edit">
            <!-- Invoice Edit Left starts -->
            <div class="col-xl-9 col-md-8 col-12">
                <div class="card invoice-preview-card">

                    <div class="card-body invoice-padding">

                        @include("quotes.templates.interface." . $object->template->template_path)

                    </div>
                </div>
            </div>
            <!-- Invoice Edit Left ends -->

            <!-- Invoice Edit Right starts -->
            <div class="col-xl-3 col-md-4 col-12" style="height: 240px;">
                <div class="card quote-controls">
                    <div class="card-body">
                        <button type="button"
                                class="btn btn-outline-primary btn-block mb-75"
                                id="preview-button"
                                @click="pdfPreview('{{ route('quote-preview', $object->id) }}', 'sidebar-pdf-preview')"
                        >Preview</button>
                        <button type="button" class="btn btn-success btn-block mb-75" id="save-button">Save</button>
                        <button type="button" class="btn btn-warning btn-block mb-75" id="lock-button">Finalise & Lock</button>
                        <a class="btn btn-outline-warning btn-block mb-75" id="return-button" href="{{ route('quotes') }}">Return to list of Quotes</a>
                    </div>
                </div>
            </div>
            <!-- Invoice Edit Right ends -->
        </div>

        @include("pdfTemplates.preview", ['title' => 'Quote'])

    </section>

    {{ Form::close() }}
@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/forms/repeater/jquery.repeater.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/pickers/flatpickr/flatpickr.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>

@endsection


@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.clientId = {!! json_encode($clientId) !!};
        window.pageData.clients = {!! json_encode($clients) !!};
        window.pageData.siteId = {!! json_encode($siteId) !!};
        window.pageData.sites = {!! json_encode($sites) !!};
        window.pageData.users = {!! json_encode($users) !!};
        window.pageData.opportunityId = {!! json_encode($opportunityId) !!};
        window.pageData.opportunities = {!! json_encode($opportunities) !!};
        window.pageData.version = {!! json_encode($object->version_number) !!};
        window.pageData.id = {!! json_encode($object->id) !!};
        window.pageData.name = {!! json_encode($object->name) !!};
        window.pageData.services = {!! json_encode($services) !!};


        window.pageData.metaData = {!! $object->meta_data !!}
        window.pageData.inventories = {!! json_encode($inventories) !!}

        $(document).ready(function() {
            $('#preview-button').click(function() { // This is used to submit live editing content to the preview page without saving
                $('#quote-form').attr('target', 'preview');
                $('#quote-form').attr('action', "{{ route('quote-preview', $object->id) }}").submit();
            });
            $('#save-button').click(function() {
                $('#quote-form').attr('target', null);
                $('#quote-form').attr('action', "{{ route('quote-update', $object->id) }}").submit();
            });
            $('#lock-button').click(function() {
                $('#quote-form').attr('target', null);
                $('#quote-form').attr('action', "{{ route('quote-lock', $object->id) }}").submit();
            });
        });
    </script>
    @include('panels.dropDownPickersScripts')

    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/pages/app-invoice.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/quote-page-breaker.js') }}"></script>
@endsection
