@extends('layouts.contentLayoutMaster')

@section('title')
    Create a Return
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('returns'),
            'name' =>'Returns'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::open(['route' => ['return-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
    {!! Form::hidden('orderId', old('orderId', $orderId), ['id' => 'orderId']) !!}
    {!! Form::hidden('inventoryListData', old('inventoryListData', json_encode($object->inventoryListData)), ['id' => 'inventoryListData']) !!}
    @csrf
    <div class="form-body">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            <div class="row match-height">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Return Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('cwt_return_number', 'CWT Return Number *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('cwt_return_number', old('cwt_return_number'), [
                                                        'id' => 'cwt_return_number',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['cwt_return_number'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('supplier_id', 'Supplier') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('supplier_id', $suppliers['options'], old('supplier_id', $supplierId),
                                                        ['id' => 'supplier_id', 'class' => 'select2 form-control'] + $validationRules['supplier_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id', $clientId),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12" id="Site">
                                        <div class="form-group">
                                            {!! Form::label('site_id', 'Site') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('site_id', $sites['options'], old('site_id', $siteId),
                                                        ['id' => 'site_id', 'class' => 'select2 form-control'] + $validationRules['site_id'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('order_ids', 'Orders') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('order_id', $orders['options'], old('order_id', $orderId),
                                                        ['id' => 'order_id', 'class' => 'select2 form-control'] + $validationRules['order_id'], $orders['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>

                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('return_date', 'Return Date *') !!}
                                            <div class="controls">
                                                <input type="hidden" name="return_date" :value="return_date">
                                                <date-picker
                                                    id="return_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="return_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('description', 'Description') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::textarea('description', old('details'), [
                                                        'id' => 'description',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['description'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('reason_for_return', 'Reason for return') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('reason_for_return', old('reason_for_return'), [
                                                        'id' => 'reason_for_return',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['reason_for_return'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('credit_note_received', 'Credit Note Received') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('credit_note_received', old('credit_note_received'), [
                                                        'id' => 'credit_note_received',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['credit_note_received'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('credit_note_received_date', 'Credit note received date') !!}
                                            <div class="controls">
                                                <input type="hidden" name="credit_note_received_date" :value="credit_note_received_date">
                                                <date-picker
                                                    id="credit_note_received_date"
                                                    value-type="YYYY-MM-DD"
                                                    time-title-format="D MMM YYYY"
                                                    title-format="D MMM YYYY"
                                                    format="D MMM YYYY"
                                                    input-class="form-control"
                                                    type="date"
                                                    v-model="credit_note_received_date">
                                                </date-picker>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('delivery_company', 'Delivery Company') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('delivery_company', old('delivery_company'), [
                                                        'id' => 'delivery_company',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['delivery_company'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('rma', 'RMA') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('rma', old('rma'), [
                                                        'id' => 'rma',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['rma'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('returns')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    {{ Form::close() }}

@endsection

@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
    </script>

    @include('panels.dropDownPickersScripts')
@endsection
