@extends('layouts.contentLayoutMaster')

@section('title')
    Returns
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>'/',
            'name' =>'Dashboard'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('content')
    <section id="data-list-view" class="data-list-view-header">

        <!-- DataTable starts -->
        <div class="table-responsive">
            <table
                class="table data-list-view data-list-view-compact"
                data-order='[[ 2, "desc" ]]'
                data-selectRow="false">
                <thead>
                <tr>
                    <th class="edit"></th>
                    <th>CWT Return Number</th>
                    <th>Return Date</th>
                    <th>Company</th>
                    <th>Site</th>
                    <th>Supplier</th>
                </tr>
                </thead>
                <tbody>
                @foreach($returns as $return)
                    <tr data-id="{{ $return->id }}">
                        <td>
                            <div class="one-line">
                                <a href="{{ route('return-edit', $return->id) }}">
                                    <button
                                        type="button"
                                        class="btn btn-icon btn-icon rounded-circle btn-flat-primary waves-effect waves-light"
                                        data-toggle="tooltip"
                                        data-placement="bottom"
                                        title="Edit"
                                        data-original-title="Edit"
                                    >
                                        <i class="feather icon-edit-2"></i>
                                    </button>
                                </a>
                                @if(\Auth::user()->isSuperAdmin())
                                    @include('elements.deleteButtonWithConfirmBox', [
                                        'confirmMessage' => 'Are you sure you want to delete this return record?',
                                        'successRoute' => route('return-delete', $return->id),
                                    ])
                                @endif
                            </div>
                        </td>
                        <td><a href="{{ route('return-edit', $return->id) }}">{{ $return->cwt_return_number }}</a></td>
                        <td data-sort="{{ \Carbon\Carbon::parse($return->return_date)->format(env('SORT_DATE_FORMAT')) }}">
                            {{ \Carbon\Carbon::parse($return->return_date)->format(env('DEFAULT_DATE_FORMAT')) }}
                        </td>
                        <td>
                            @if($return->client)
                                <a href="{{ route('client-view', $return->client->id) }}">{{ $return->clientName() }}</a>
                            @endif
                        </td>
                        <td>
                            @if($return->site)
                                <a href="{{ route('site-view', $return->site->id) }}">{{ $return->siteName() }}</a>
                            @endif
                        </td>
                        <td>{{ $return->supplierName() }}</td>
                    </tr>
                @endforeach
                </tbody>
            </table>
        </div>
        <!-- DataTable ends -->
        {{-- @include('clients.sidebar-create') --}}
    </section>
    <!-- Data list view end -->

@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    {{-- Page js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
@endsection

