@extends('layouts.contentLayoutMaster')

@section('title')
	Create a Site
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('sites'),
            'name' =>'Sites'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')


	@include('elements.messages-error')

	{!! Form::open(['route' => ['site-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
	@csrf
	<div class="form-body">

	<!-- // Basic multiple Column Form section start -->
		<section id="multiple-column-form">
			<div class="row match-height">

				<div class="col-12">


					<div class="card">
						<div class="card-header">
							<h4 class="card-title">Site Details</h4>
						</div>
						<div class="card-content">
							<div class="card-body">
								<div class="row">
									<div class="col-md-6 col-12">
										<div class="form-group">
											{!! Form::label('name', 'Site Name *') !!}
											<div class="controls">
												{!!
													Form::text('name', old('name'), [
														'id' => 'name',
														'class' => 'form-control',
													] + $validationRules['name'])
												!!}
											</div>
										</div>
									</div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('client_id', 'Company *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_id', $clients['options'], old('client_id', $selectedClientId),
                                                        ['id' => 'client_id', 'class' => 'select2 form-control'] + $validationRules['client_id'], $clients['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
									<div class="col-md-6 col-12">
										<div class="form-group">
											{!! Form::label('telephone', 'Telephone') !!}
											<div class="controls">
												{!!
													Form::text('telephone', old('telephone'), [
														'id' => 'telephone',
														'class' => 'form-control',
													] + $validationRules['telephone'])
												!!}
											</div>
										</div>
									</div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('fax', 'Fax') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('fax', old('fax'), [
                                                        'id' => 'fax',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['fax'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
									<div class="col-md-6 col-12">
										<div class="form-group">
											{!! Form::label('email', 'Email') !!}
											<div class="controls">
												{!!
													Form::email('email', old('email'), [
														'id' => 'email',
														'class' => 'form-control',
													] + $validationRules['email'])
												!!}
											</div>
										</div>
									</div>
									<div class="col-md-6 col-12">
										<div class="form-group">
											{!! Form::label('website', 'Website') !!}
											<div class="controls">
												{!!
													Form::text('website', old('website'), [
														'id' => 'website',
														'class' => 'form-control',
													] + $validationRules['website'])
												!!}
											</div>
										</div>
									</div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('status', 'Status') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('status', $statuses['options'], old('status', app('request')->input('status') != null ? app('request')->input('status') : null),
                                                    [
                                                        'id' => 'status',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['status'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('subtype', 'Sub Type') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('subtype', $subTypes['options'], old('subtype', app('request')->input('subtype') != null ? app('request')->input('subtype') : null),
                                                    [
                                                        'id' => 'subtype',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['subtype'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('site_manager_id', 'Client Manager') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_manager_id', $clientManagers['options'], old('client_manager_id', app('request')->input('client_manager_id') != null ? app('request')->input('client_manager_id') : null),
                                                    [
                                                        'id' => 'client_manager_id',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['client_manager_id'], $clientManagers['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('worksheet_id', 'Default Worksheet') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('worksheet_id', $worksheets['options'], old('worksheet_id', app('request')->input('worksheet_id') != null ? app('request')->input('worksheet_id') : env('DEFAULT_WORKSHEET_ID')),
                                                    [
                                                        'id' => 'worksheet_id',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['worksheet_id'], $worksheets['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>

								</div>
							</div>
						</div>
					</div>
				</div>

				<div class="col-md-4 col-12">
                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Company Address</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">

                                    @include('elements.address', [
                                        'namePreFix' => 'registered',
                                        'countries' => $countries,
                                        'type' => 'registered',
                                        'validationRules' => $validationRules
                                    ])

                                    <div class="col-12 py-75">
                                        <input id="billing_address" name="billing_address" type="checkbox" value="1">
                                        <label for="billing_address">Use same address for <strong>Invoice</strong></label>
                                    </div>
                                    <div class="col-12 py-75">
                                        <input id="shipping_address" name="shipping_address" type="checkbox" value="1">
                                        <label for="shipping_address">Use same address for <strong>Delivery</strong></label>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>

				<div class="col-12">
					<div class="card">
						<div class="card-content">
							<div class="card-body">
								<div class="row">
									<div class="col-12">
										<button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
										<a class="btn btn-flat-dark mb-1 p-1" href="{{route('sites')}}">Cancel</a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>

		</div>
	{{ Form::close() }}


@endsection
