@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('suppliers'),
            'name' =>'Suppliers'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">

@endsection

@section('page-style')

@endsection

@section('object-toolbar')

    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('supplier-view', $object->id) }}"
    ><i class="feather icon-grid"></i> View
    </b-button>

@endsection

@section('content')

    @include('elements.messages-error')

    
    <div class="">

        <!-- // Basic multiple Column Form section start -->
        <section id="multiple-column-form">
            {!! Form::model($object, ['route' => ['supplier-update', $object->id], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}
            @csrf
            <div class="row match-height form-body">

                <div class="col-12">
                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Supplier Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('name', 'Company Name') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('name', old('name'), [
                                                        'id' => 'name',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['name'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('email', 'Email') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::email('email', old('email'), [
                                                        'id' => 'email',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['email'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('website', 'Website') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('website', old('website'), [
                                                        'id' => 'website',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['website'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('telephone', 'Telephone') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('telephone', old('telephone'), [
                                                        'id' => 'telephone',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['telephone'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-md-6 col-12">
                                        <div class="form-group">
                                            {!! Form::label('fax', 'Fax') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::text('fax', old('fax'), [
                                                        'id' => 'fax',
                                                        'class' => 'form-control',
                                                    ] + $validationRules['fax'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-12 col-md-6">
                                        <div class="form-group">
                                            {!! Form::label('client_manager_id', 'Client Manager *') !!}
                                            <div class="controls">
                                                {!!
                                                    Form::select('client_manager_id', $clientManagers['options'], old('client_manager_id', app('request')->input('client_manager_id') != null ? app('request')->input('client_manager_id') : null),
                                                    [
                                                        'id' => 'client_manager_id',
                                                        'class' => 'select2 form-control',
                                                    ] + $validationRules['client_manager_id'], $clientManagers['optionAttributes'])
                                                !!}
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Save</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('suppliers')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            {{ Form::close() }}

            <div class="row">
                <div class="col-xl-5 col-lg-5 col-md-5">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <addresses :addresses="addresses" :address-types="address_types" parent-class="Supplier" parent-id="{{$object->id}}"></addresses>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>

    </div>
    

@endsection

@section('vendor-script')

@endsection

@section('page-script')

    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.parent_class = "Supplier";
        window.pageData.parent_id = {{ $object->id }};
        window.pageData.address_types = {!! json_encode($object->getAddressTypes()) !!};
    </script>
@endsection
