@extends('layouts.contentLayoutMaster')

@section('title')
    Suppliers
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>'/',
            'name' =>'Dashboard'
        ]
    ]
@endphp

@section('vendor-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
    {{-- Page Css files --}}
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('content')
    <section id="data-list-view" class="data-list-view-header">

        <!-- DataTable starts -->
        <div class="table-responsive">
            <table
                class="table data-list-view data-list-view-compact"
                data-create-route="{{route('supplier-create')}}"
                data-order='[[ 1, "asc" ]]'
                data-selectRow="false"
            >
                <thead>
                <tr>
                    <th class="edit"></th>
                    <th>Supplier</th>
                    <th>Address</th>
                </tr>
                </thead>
                <tbody>
                @foreach($suppliers as $supplier)
                    <tr data-id="{{ $supplier->id }}">
                        <td>
                            <div class="one-line">
                                <a href="{{route('supplier-view', $supplier->id)}}"
                                    class="btn btn-icon btn-icon rounded-circle btn-flat-success waves-effect waves-light"
                                    data-toggle="tooltip"
                                    data-placement="bottom"
                                    title="View"
                                    data-original-title="View"
                                >
                                    <i class="feather icon-eye"></i>
                                </a>
                                <a href="{{ route('supplier-edit', $supplier->id) }}">
                                    <button
                                        type="button"
                                        class="btn btn-icon btn-icon rounded-circle btn-flat-primary waves-effect waves-light"
                                        data-toggle="tooltip"
                                        data-placement="bottom"
                                        title="Edit"
                                        data-original-title="Edit"
                                    >
                                        <i class="feather icon-edit-2"></i>
                                    </button>
                                </a>
                                @if(\Auth::user()->isSuperAdmin())
                                    @include('elements.deleteButtonWithConfirmBox', [
                                        'confirmMessage' => 'Are you sure you want to delete this supplier?',
                                        'successRoute' => route('supplier-delete', $supplier->id),
                                    ])
                                @endif
                            </div>
                        </td>
                        <td><a href="{{ route('supplier-edit', $supplier->id) }}">{{ $supplier->name }}</a></td>
                        <td>{{ $supplier->registeredAddress ? $supplier->registeredAddress->fullAddress : ''}}</td>
                    </tr>
                @endforeach
                </tbody>
            </table>
        </div>
        <!-- DataTable ends -->
        {{-- @include('clients.sidebar-create') --}}
    </section>
    <!-- Data list view end -->

@endsection

@section('vendor-script')
    {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
@endsection

@section('page-script')
    {{-- Page js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
@endsection

