@extends('layouts.contentLayoutMaster')

@section('title')
    {{ $object->name }}
@endsection

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
@endsection

@section('page-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection

@section('object-toolbar')


    <b-button

        variant="outline-primary"
        class="mb-1"
        href="{{ route('supplier-edit', $object->id) }}"
    ><i class="feather icon-edit"></i> Edit
    </b-button>

@endsection

@section('content')
    @include('elements.messages-error')

    <section id="multiple-column-form">
        <div class="row match-height">
            <div class="col-12">
                <div class="card">
                    <div class="card-body pb-0">

                        <div class="pull-right">

                            <button
                                type="button"
                                class="btn btn-primary mb-1 p-1 show-data-sidebar"
                                data-sidebar-content="sidebar-documents">
                                <i class="feather icon-paperclip"></i>
                                Documents
                            </button>
                        </div>

                    </div>
                </div>
            </div>

            <div class="col-xl-4 col-lg-4 col-md-4">
                <div class="card">
                    <div class="card-header object-toolbar">
                        <h4 class="card-title mb-25">Supplier Details</h4>
                    </div>

                    <div class="card-content">
                        <div class="card-body">
                            <div class="row">
                                <div class="col-xl-12 col-lg-12 mb-1">
                                    <h6 class="mb-0">{{ $object->name }}</h6>
                                    <small>Company Name</small>
                                    @if (!empty($object->email))
                                        <div class="d-flex align-items-center">
                                            <div class="color-box bg-light-success">
                                                <i data-feather="trending-up" class="text-success"></i>
                                            </div>
                                            <div class="mb-1">
                                                <h5 class="mb-0">
                                                    {{$object->email}}
                                                </h5>
                                                <small><i class="feather icon-mail"></i> Email</small>
                                            </div>
                                        </div>
                                    @endif
                                    @if (!empty($object->telephone))
                                        <div class="d-flex align-items-center">
                                            <div class="color-box bg-light-success">
                                                <i data-feather="trending-up" class="text-success"></i>
                                            </div>
                                            <div class="mb-1">
                                                <h5 class="mb-0">
                                                    {{$object->telephone}}
                                                </h5>
                                                <small><i class="feather icon-phone"></i> Telephone</small>
                                            </div>
                                        </div>
                                    @endif
                                    @if (!empty($object->fax))
                                        <div class="d-flex align-items-center">
                                            <div class="color-box bg-light-success">
                                                <i data-feather="trending-up" class="text-success"></i>
                                            </div>
                                            <div class="mb-1">
                                                <h5 class="mb-0">
                                                    {{$object->fax}}
                                                </h5>
                                                <small><i class="feather icon-phone"></i> Fax</small>
                                            </div>
                                        </div>
                                    @endif
                                    @if (!empty($object->website))
                                        <div class="d-flex align-items-center">
                                            <div class="color-box bg-light-success">
                                                <i data-feather="trending-up" class="text-success"></i>
                                            </div>
                                            <div class="mb-1">
                                                <h5 class="mb-0">
                                                    {{$object->website}}
                                                </h5>
                                                <small><i class="feather icon-link"></i> Website</small>
                                            </div>
                                        </div>
                                    @endif
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-5 col-lg-5 col-md-5">
                <div class="card">
                    <div class="card-content">
                        <div class="card-body">
                            <addresses :addresses="addresses" :address-types="address_types" parent-class="Supplier" parent-id="{{$object->id}}"></addresses>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-xl-3 col-lg-3 col-md-3">
                <div class="card plan-card border-primary">
                    <div class="card-header d-flex justify-content-between align-items-center pt-75 pb-25">
                        <h5 class="mb-0"> Last Update </h5>
                        <small class="text-muted w-100">{{$object->updated_at}}</small>
                    </div>
                    <div class="card-body">
                        <b-button
                            block
                            variant="primary"
                            class="btn btn-primary text-center btn-block"
                            v-b-toggle.sidebar-contacts
                        ><i class="feather icon-phone-call mr-50"></i> Contact List
                        </b-button>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <b-sidebar id="sidebar-contacts" bg-variant="white" title="Contacts" right shadow backdrop class="bg-white" width="85%">
        <div class="px-1 py-2">
            <div class="data-list-view-header">
                <div class="table-responsive">
                    <table class="table data-list-view" data-create-route="{{route('contact-create')}}?supplierId={{ $object->id }}" data-order='[[ 1, "asc" ]]'>
                        <thead>
                        <tr>
                            <th></th>
                            <th>Name</th>
                            <th>Main telephone</th>
                            <th>DDI</th>
                            <th>Mobile</th>
                            <th>Email</th>
                            <th class="edit"></th>
                        </tr>
                        </thead>
                        <tbody>
                        @foreach($object->contacts as $contact)
                            <tr data-id="{{ $contact->id }}">
                                <td></td>
                                <td>
                                    <a href="{{ route('contact-edit', $contact->id) }}">{{ $contact->fullName }}</a>
                                </td>
                                <td>{{$contact->telephone}}</td>
                                <td>{{$contact->ddi}}</td>
                                <td>{{$contact->mobile}}</td>
                                <td>
                                    @if (!empty($contact->email))
                                        <a href="mailto:{{$contact->email}}">{{$contact->email}}</a>
                                    @endif
                                </td>
                                <td>
                                    <div class="float-right">
                                        <a href="{{route('contact-edit', $contact->id)}}">
                                            <button type="button" class="btn btn-icon btn-icon rounded-circle btn-primary mr-1 waves-effect waves-light" data-toggle="tooltip" data-placement="bottom" title="Edit" data-original-title="Edit">
                                                <i class="feather icon-edit-2"></i>
                                            </button>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </b-sidebar>
@endsection

@section('vendor-script')
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
@endsection

@section('page-script')

    <script type="text/javascript">
        window.pageData = {!! json_encode($object) !!};
        window.pageData.parent_class = "Supplier";
        window.pageData.parent_id = {{ $object->id }};
        window.pageData.address_types = {!! json_encode($object->getAddressTypes()) !!};
    </script>

    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/datatables/datatable.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>

@endsection
