@extends('layouts.contentLayoutMaster')

@section('title')
    Create an User
@endsection

@php
    $breadcrumbs = [
        [
            'link'=>route('users'),
            'name' =>'Users'
        ]
    ]
@endphp

@section('vendor-style')
    <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/forms/select/select2.css') }}">
@endsection

@section('content')

    @include('elements.messages-error')

    {!! Form::open(['route' => ['users-store'], 'method' => 'post', 'class' => 'form form-vertical', 'novalidate']) !!}

        @csrf

        <section id="multiple-column-form">

            <div class="row match-height">
                <div class="col-md-6 col-12">
                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Personal Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">

                                <div class="form-body">

                                    <div class="row">
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('first_name', 'First Name *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('first_name', old('first_name'), [
                                                            'id' => 'first_name',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['first_name'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('last_name', 'Last Name *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('last_name', old('last_name'), [
                                                            'id' => 'last_name',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['last_name'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('email', 'Email *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('email', old('email'), [
                                                            'id' => 'email',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['email'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('dob', 'DoB') !!}
                                                <div class="controls">
                                                    <input type="hidden" name="dob" :value="dob">
                                                    <date-picker
                                                            id="dob"
                                                            value-type="YYYY-MM-DD"
                                                            time-title-format="D MMM YYYY"
                                                            title-format="D MMM YYYY"
                                                            format="D MMM YYYY"
                                                            input-class="form-control"
                                                            type="date"
                                                            v-model="dob">
                                                    </date-picker>
                                                </div>
                                            </div>
                                        </div>

                                    </div>
                                    <div class="row">
                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('password', 'Password *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::password('password', [
                                                            'id' => 'password',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['password'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">

                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('telephone', 'Telephone') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('telephone', old('telephone'), [
                                                            'id' => 'telephone',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['telephone'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('mobile', 'Mobile') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('mobile', old('mobile'), [
                                                            'id' => 'mobile',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['mobile'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-6 col-12">

                    <div class="card">
                        <div class="card-header">
                            <h4 class="card-title">Employment Details</h4>
                        </div>
                        <div class="card-content">
                            <div class="card-body">

                                <div class="form-body">

                                    <div class="row">

                                        <div class="col-12">
                                            <div class="form-group">
                                                {!! Form::label('job_title', 'Job Title') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('job_title', old('job_title'), [
                                                            'id' => 'job_title',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['job_title'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-12">
                                            <div class="form-group">
                                                {!! Form::label('employee_type_ids', 'Employee Type *') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::select('employee_type_ids[]', $employeeTypes['options'], old('employee_type_ids', []),
                                                        [
                                                            'id' => 'employee_type_ids',
                                                            'class' => 'select2 form-control',
                                                            'multiple' => 'multiple'
                                                        ] + $validationRules['employee_type_ids'], $employeeTypes['optionAttributes'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('employee_number', 'Employee Number') !!}
                                                <div class="controls">
                                                    {!!
                                                        Form::text('employee_number', old('employee_number'), [
                                                            'id' => 'employee_number',
                                                            'class' => 'form-control',
                                                        ] + $validationRules['employee_number'])
                                                    !!}
                                                </div>
                                            </div>
                                        </div>

                                        <div class="col-md-6 col-12">
                                            <div class="form-group">
                                                {!! Form::label('start_date', 'Start Date') !!}
                                                <div class="controls">
                                                    <input type="hidden" name="start_date" :value="start_date">
                                                    <date-picker
                                                            id="start_date"
                                                            value-type="YYYY-MM-DD"
                                                            time-title-format="D MMM YYYY"
                                                            title-format="D MMM YYYY"
                                                            format="D MMM YYYY"
                                                            input-class="form-control"
                                                            type="date"
                                                            v-model="start_date">
                                                    </date-picker>
                                                </div>
                                            </div>
                                        </div>

                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                </div>
                <div class="col-12">
                    <div class="card">
                        <div class="card-content">
                            <div class="card-body">

                                <div class="row">

                                    <div class="col-12">
                                        <button type="submit" class="btn btn-primary mr-1 mb-1">Create</button>
                                        <a class="btn btn-flat-dark mb-1 p-1" href="{{route('users')}}">Cancel</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

        </section>
    {{ Form::close() }}
@endsection

@section('vendor-script')

@endsection

@section('page-script')
    <script type="text/javascript">
        window.pageData = {!! json_encode($user) !!};
    </script>
@endsection
