@extends('layouts.contentLayoutMaster')

@section('title', 'Users')

@php
    $breadcrumbs = [
        [
            'link'=>'/',
            'name' =>'Dashboard'
        ]
    ]
@endphp

@section('vendor-style')
        {{-- Page Css files --}}
        <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/datatables.min.css') }}">
        <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/file-uploaders/dropzone.min.css') }}">
        <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('vendors/css/tables/datatable/extensions/dataTables.checkboxes.css') }}">
@endsection

@section('page-style')
        {{-- Page Css files --}}
        <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/plugins/file-uploaders/dropzone.css') }}">
        <link rel="stylesheet" href="{{ \App\Helpers\Helpers::assetLink('css/pages/data-list-view.css') }}">
@endsection


@section('content')
    <section id="data-list-view" class="data-list-view-header">
        <!-- DataTable starts -->
        <div class="table-responsive">
            <table
                class="table data-list-view data-list-view-compact"
                data-create-route="{{route('user-create')}}"
                data-order='[[ 0, "asc" ]]'
                data-selectRow="false"
            >
                <thead>
                    <tr>
                        <th>Name</th>
                        <th>Contact Number</th>
                        <th>Employee Type</th>
                        <th>Employee Number</th>
                        <th>Job Title</th>
                        <th class="edit"></th>
                    </tr>
                </thead>
                <tbody>
                @foreach($users as $user)

                    <tr>
                        <td><a href="{{ route('user-edit', $user->id) }}">{{ $user->first_name }} {{$user->last_name}}</a>
                            @if(!empty($user->email))
                                <a href="mailto:{{$user->email}}" target="_blank" data-toggle="tooltip" data-placement="bottom" title="{{$user->email}}" data-original-title="Email"><i class="feather icon-mail"></i><span class="d-none">{{$user->email}}</span></a>
                            @endif
                        </td>

                        <td>
                            @if(!empty($user->telephone))
                                <div><a href="tel:{{str_replace(' ', '', $user->telephone)}}"><i class="feather icon-phone"></i> {{ $user->telephone }}</a></div>
                            @endif
                            @if(!empty($user->mobile))
                                <div><a href="tel:{{str_replace(' ', '', $user->mobile)}}"><i class="feather icon-smartphone"></i> {{ $user->mobile }}</a></div>
                            @endif
                        </td>
                        <td>
                            @if(!empty($user->TypeNames))
                                @php
                                    $typeNameArray =  explode(",", $user->TypeNames);

                                    $typeColor = [
                                        "Operative" => "success",
                                        "System Admin" => "info",
                                        "Default" => "secondary"
                                    ];
                                @endphp
                                @foreach ($typeNameArray as $typeName)
                                    @php
                                        $typeName = trim($typeName);
                                        $currentTypeColor = (array_key_exists($typeName, $typeColor)) ? $typeColor[$typeName] : $typeColor["Default"];
                                    @endphp

                                    <div class="badge badge-{{$currentTypeColor}}">{{$typeName}}</div>
                                @endforeach
                            @endif

                        </td>
                        <td>{{ $user->employee_number }}</td>
                        <td>{{ $user->job_title }}</td>
                        <td>
                            <div class="one-line">
                                <a href="{{ route('user-edit', $user->id) }}">
                                    <button
                                        type="button"
                                        class="btn btn-icon btn-icon rounded-circle btn-flat-primary waves-effect waves-light"
                                        data-toggle="tooltip"
                                        data-placement="bottom"
                                        title="Edit"
                                        data-original-title="Edit"
                                    >
                                        <i class="feather icon-edit-2"></i>
                                    </button>
                                </a>
                                @if(\Auth::user()->isSuperAdmin() && \Auth::user()->id != $user->id)
                                    @if($user->activated)
                                        @include('elements.deleteButtonWithConfirmBox', [
                                            'title' => 'Deactivate',
                                            'confirmButtonText' => 'Deactivate',
                                            'iconClass' => 'icon-slash',
                                            'confirmMessage' => 'Are you sure you want to deactivate this user?',
                                            'successRoute' => route('user-deactivate', $user->id),
                                        ])
                                    @else
                                        @include('elements.deleteButtonWithConfirmBox', [
                                            'title' => 'Activate',
                                            'confirmButtonText' => 'Activate',
                                            'iconClass' => 'icon-alert-triangle',
                                            'iconColour' => 'btn-warning',
                                            'confirmMessage' => 'Are you sure you want to activate this user?',
                                            'successRoute' => route('user-activate', $user->id),
                                        ])
                                    @endif

                                @endif
{{--                                <a href="{{ route('user-calendar', $user->id) }}">--}}
{{--                                    <button data-toggle="tooltip" data-placement="bottom" title="Schedule" data-original-title="Schedule"  type="button" class="btn btn-icon btn-icon rounded-circle btn-warning mr-1 waves-effect waves-light">--}}
{{--                                        <i class="feather icon-calendar"></i>--}}
{{--                                    </button>--}}
{{--                                </a>--}}
{{--                                <a href="{{ route('user-email-sync', $user->id) }}">--}}
{{--                                    <button data-toggle="tooltip" data-placement="bottom" data-original-title="Sync emails" title="" type="button" class="btn btn-icon btn-icon rounded-circle btn-warning mr-1 waves-effect waves-light">--}}
{{--                                        <i class="feather icon-refresh-cw"></i>--}}
{{--                                    </button>--}}
{{--                                </a>--}}
                            </div>
                            {{-- <a href="{{route('user-delete', $user->id)}}">Delete</a> --}}
                        </td>
                    </tr>
                @endforeach
                </tbody>
            </table>
        </div>
        <!-- DataTable ends -->
        {{-- @include('clients.sidebar-create') --}}
    </section>

@endsection

@section('vendor-script')
  {{-- Vendor js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/extensions/dropzone.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.buttons.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.bootstrap4.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/buttons.bootstrap.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/dataTables.select.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/tables/datatable/datatables.checkboxes.min.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('vendors/js/forms/select/select2.full.min.js') }}"></script>
@endsection

@section('page-script')
  {{-- Page js files --}}
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/ui/data-list-view.js') }}"></script>
    <script src="{{ \App\Helpers\Helpers::assetLink('js/scripts/forms/select/form-select2.js') }}"></script>
@endsection

