const mix = require('laravel-mix');
const exec = require('child_process').exec;
require('dotenv').config();

publicPath = '../public/';
assetsPath = 'resources/';

mix.setPublicPath(publicPath);

/*
 |--------------------------------------------------------------------------
 | Mix Asset Management
 |--------------------------------------------------------------------------
 |
 | Mix provides a clean, fluent API for defining some Webpack build steps
 | for your Laravel application. By default, we are compiling the Sass
 | file for the application as well as bundling up all the JS files.
 |
 */

const glob = require('glob')
const path = require('path')

/*
 |--------------------------------------------------------------------------
 | Vendor assets
 |--------------------------------------------------------------------------
 */

function mixAssetsDir(query, cb) {
  (glob.sync(assetsPath + '' + query) || []).forEach(f => {
    f = f.replace(/[\\\/]+/g, '/');
    cb(f, f.replace(assetsPath, publicPath));
  });
}

const sassOptions = {
  // precision: 5
};

// plugins Core stylesheets
mixAssetsDir('sass/plugins/**/!(_)*.scss', (src, dest) => mix.sass(src, dest.replace(/(\\|\/)sass(\\|\/)/, '$1css$2').replace(/\.scss$/, '.css'), sassOptions));

// themes Core stylesheets
mixAssetsDir('sass/themes/**/!(_)*.scss', (src, dest) => mix.sass(src, dest.replace(/(\\|\/)sass(\\|\/)/, '$1css$2').replace(/\.scss$/, '.css'), sassOptions));

// pages Core stylesheets
mixAssetsDir('sass/pages/**/!(_)*.scss', (src, dest) => mix.sass(src, dest.replace(/(\\|\/)sass(\\|\/)/, '$1css$2').replace(/\.scss$/, '.css'), sassOptions));

// Core stylesheets
mixAssetsDir('sass/core/**/!(_)*.scss', (src, dest) => mix.sass(src, dest.replace(/(\\|\/)sass(\\|\/)/, '$1css$2').replace(/\.scss$/, '.css'), sassOptions));

// script js
mixAssetsDir('js/scripts/**/*.js', (src, dest) => mix.scripts(src, dest));

/*
 |--------------------------------------------------------------------------
 | Vendor assets
 |--------------------------------------------------------------------------
 */
 mixAssetsDir('vendors/js/**/*.js', (src, dest) => mix.scripts(src, dest));
 mixAssetsDir('vendors/css/**/*.css', (src, dest) => mix.copy(src, dest));
 mixAssetsDir('vendors/css/editors/quill/fonts/', (src, dest) => mix.copy(src, dest));

/*
 |--------------------------------------------------------------------------
 | Application assets
 |--------------------------------------------------------------------------
 */

mix.copyDirectory(assetsPath + 'images', publicPath + 'images');
mix.copy(assetsPath + 'manifest.json', publicPath + 'manifest.json');
mix.copyDirectory(assetsPath + 'fonts', publicPath + 'fonts');

mix
    .js(assetsPath + 'js/core/app-menu.js', publicPath + 'js/core')
    .js(assetsPath + 'js/core/app.js', publicPath + 'js/core')
    .js(assetsPath + 'js/app.js', publicPath + 'js')
    .js(assetsPath + 'js/sw.js', publicPath + '')
    .js(assetsPath + 'js/scripts/components.js', publicPath + 'js/scripts')
    .js(assetsPath + 'js/scripts/footer.js', publicPath + 'js/scripts')
    .js(assetsPath + 'js/scripts/datatables/*', publicPath + 'js/scripts/datatables/datatables.js')
    .js(assetsPath + 'js/scripts/extensions/*', publicPath + 'js/scripts/extensions/extensions.js')
    .js(assetsPath + 'js/scripts/ui/data-list-view.js', publicPath + 'js/scripts/ui/data-list-view.js')
    .js(assetsPath + 'js/scripts/ui/quote-page-breaker.js', publicPath + 'js/scripts/ui/quote-page-breaker.js')
    .js(assetsPath + 'js/scripts/forms/validation/jqBootstrapValidation.js', publicPath + 'js/scripts/forms/validation/jqBootstrapValidation.js')
    .js(assetsPath + 'js/scripts/forms/validation/form-validation.js', publicPath + 'js/scripts/forms/validation/form-validation.js')
    .js(assetsPath + 'js/scripts/forms/select/form-select2.js', publicPath + 'js/scripts/forms/select/form-select2.js')
    .js(assetsPath + 'js/scripts/datatables/user-datatable.js', publicPath + 'js/scripts/datatables/user-datatable.js')
    .js(assetsPath + 'js/scripts/pages/bootstrap-toast.js', publicPath + 'js/scripts/pages/bootstrap-toast.js')
    .js(assetsPath + 'js/scripts/pages/app-invoice.js', publicPath + 'js/scripts/pages/app-invoice.js')
    .js(assetsPath + 'js/app/app.js', publicPath + 'js/app/app.js').vue({ version: 2 })

    .sass(assetsPath + 'sass/bootstrap.scss', publicPath + 'css')
    .sass(assetsPath + 'sass/bootstrap-extended.scss', publicPath + 'css')
    .sass(assetsPath + 'sass/colors.scss', publicPath + 'css')
    .sass(assetsPath + 'sass/components.scss', publicPath + 'css')
    .sass(assetsPath + 'sass/custom-rtl.scss', publicPath + 'css')
    .sass(assetsPath + 'sass/custom-laravel.scss', publicPath + 'css')
    .version();


mix.then(() => {
  if (process.env.MIX_CONTENT_DIRECTION === "rtl") {
    let command = `node ${path.resolve('node_modules/rtlcss/bin/rtlcss.js')} -d -e ".css" ../public/css/ ../public/css/`;
    exec(command, function (err, stdout, stderr) {
      if (err !== null) {
        console.log(err);
      }
    });
  }
});

mix.webpackConfig({
  // stats: {
  //   children: true,
  // },
  devServer: {
      proxy: {
          '*': 'http://localhost:8000'
      }
  }
});